# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomizedCfgArgs', 'CustomizedCfg']

@pulumi.input_type
class CustomizedCfgArgs:
    def __init__(__self__, *,
                 customized_cfg_content: pulumi.Input[builtins.str],
                 customized_cfg_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]] = None):
        """
        The set of arguments for constructing a CustomizedCfg resource.
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        """
        pulumi.set(__self__, "customized_cfg_content", customized_cfg_content)
        pulumi.set(__self__, "customized_cfg_name", customized_cfg_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> pulumi.Input[builtins.str]:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @customized_cfg_content.setter
    def customized_cfg_content(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "customized_cfg_content", value)

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> pulumi.Input[builtins.str]:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @customized_cfg_name.setter
    def customized_cfg_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "customized_cfg_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CustomizedCfgState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_id: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 listeners: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgListenerArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomizedCfg resources.
        :param pulumi.Input[builtins.str] created_time: 个性化配置的创建时间。
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_id: 个性化配置的 ID 。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        :param pulumi.Input[builtins.str] status: 个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        :param pulumi.Input[builtins.str] updated_time: 个性化配置的最近操作时间。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if customized_cfg_content is not None:
            pulumi.set(__self__, "customized_cfg_content", customized_cfg_content)
        if customized_cfg_id is not None:
            pulumi.set(__self__, "customized_cfg_id", customized_cfg_id)
        if customized_cfg_name is not None:
            pulumi.set(__self__, "customized_cfg_name", customized_cfg_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if listeners is not None:
            pulumi.set(__self__, "listeners", listeners)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @customized_cfg_content.setter
    def customized_cfg_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customized_cfg_content", value)

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的 ID 。
        """
        return pulumi.get(self, "customized_cfg_id")

    @customized_cfg_id.setter
    def customized_cfg_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customized_cfg_id", value)

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @customized_cfg_name.setter
    def customized_cfg_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customized_cfg_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def listeners(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgListenerArgs']]]]:
        return pulumi.get(self, "listeners")

    @listeners.setter
    def listeners(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgListenerArgs']]]]):
        pulumi.set(self, "listeners", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的最近操作时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:alb/customizedCfg:CustomizedCfg")
class CustomizedCfg(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgTagArgs', 'CustomizedCfgTagArgsDict']]]]] = None,
                 __props__=None):
        """
        ALB 提供监听维度的个性化配置功能。通过控制台可以创建并管理常规的 NGINX 配置策略，在监听器详情页一键关联配置策略，无需提交工单即可完成满足业务需求的个性化配置。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_customized_cfg_demo = bytepluscc.alb.CustomizedCfg("ALBCustomizedCfgDemo",
            customized_cfg_name="ccapi-test",
            description="testdesc",
            customized_cfg_content=\"\"\"ssl_ciphers ECDHE-ECDSA-AES128-GCM-SHA256;\\x0d
        ssl_protocols TLSv1.2 TLSv1.1 TLSv1;\\x0d
        client_max_body_size 60M;\\x0d
        keepalive_timeout 77s;\\x0d
        proxy_connect_timeout 4s;\\x0d
        proxy_request_buffering off;\\x0d
        proxy_ignore_client_abort off;\\x0d
        proxy_read_timeout 60s;\\x0d
        proxy_send_timeout 60s;\\x0d
        client_header_timeout 60s;\\x0d
        client_body_timeout 60s;\\x0d
        send_timeout 60s;\\x0d
        ssl_verify_depth 3;\\x0d
        \"\"\",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/customizedCfg:CustomizedCfg example "customized_cfg_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomizedCfgArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ALB 提供监听维度的个性化配置功能。通过控制台可以创建并管理常规的 NGINX 配置策略，在监听器详情页一键关联配置策略，无需提交工单即可完成满足业务需求的个性化配置。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_customized_cfg_demo = bytepluscc.alb.CustomizedCfg("ALBCustomizedCfgDemo",
            customized_cfg_name="ccapi-test",
            description="testdesc",
            customized_cfg_content=\"\"\"ssl_ciphers ECDHE-ECDSA-AES128-GCM-SHA256;\\x0d
        ssl_protocols TLSv1.2 TLSv1.1 TLSv1;\\x0d
        client_max_body_size 60M;\\x0d
        keepalive_timeout 77s;\\x0d
        proxy_connect_timeout 4s;\\x0d
        proxy_request_buffering off;\\x0d
        proxy_ignore_client_abort off;\\x0d
        proxy_read_timeout 60s;\\x0d
        proxy_send_timeout 60s;\\x0d
        client_header_timeout 60s;\\x0d
        client_body_timeout 60s;\\x0d
        send_timeout 60s;\\x0d
        ssl_verify_depth 3;\\x0d
        \"\"\",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/customizedCfg:CustomizedCfg example "customized_cfg_id"
        ```

        :param str resource_name: The name of the resource.
        :param CustomizedCfgArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomizedCfgArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgTagArgs', 'CustomizedCfgTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomizedCfgArgs.__new__(CustomizedCfgArgs)

            if customized_cfg_content is None and not opts.urn:
                raise TypeError("Missing required property 'customized_cfg_content'")
            __props__.__dict__["customized_cfg_content"] = customized_cfg_content
            if customized_cfg_name is None and not opts.urn:
                raise TypeError("Missing required property 'customized_cfg_name'")
            __props__.__dict__["customized_cfg_name"] = customized_cfg_name
            __props__.__dict__["description"] = description
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_time"] = None
            __props__.__dict__["customized_cfg_id"] = None
            __props__.__dict__["listeners"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(CustomizedCfg, __self__).__init__(
            'bytepluscc:alb/customizedCfg:CustomizedCfg',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
            customized_cfg_id: Optional[pulumi.Input[builtins.str]] = None,
            customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            listeners: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgListenerArgs', 'CustomizedCfgListenerArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgTagArgs', 'CustomizedCfgTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'CustomizedCfg':
        """
        Get an existing CustomizedCfg resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 个性化配置的创建时间。
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_id: 个性化配置的 ID 。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        :param pulumi.Input[builtins.str] status: 个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        :param pulumi.Input[builtins.str] updated_time: 个性化配置的最近操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomizedCfgState.__new__(_CustomizedCfgState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["customized_cfg_content"] = customized_cfg_content
        __props__.__dict__["customized_cfg_id"] = customized_cfg_id
        __props__.__dict__["customized_cfg_name"] = customized_cfg_name
        __props__.__dict__["description"] = description
        __props__.__dict__["listeners"] = listeners
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return CustomizedCfg(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的 ID 。
        """
        return pulumi.get(self, "customized_cfg_id")

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def listeners(self) -> pulumi.Output[Sequence['outputs.CustomizedCfgListener']]:
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.CustomizedCfgTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的最近操作时间。
        """
        return pulumi.get(self, "updated_time")

