# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EndpointPublicAddressArgs', 'EndpointPublicAddress']

@pulumi.input_type
class EndpointPublicAddressArgs:
    def __init__(__self__, *,
                 eip_id: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a EndpointPublicAddress resource.
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "instance_id", instance_id)
        if new_address_prefix is not None:
            pulumi.set(__self__, "new_address_prefix", new_address_prefix)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if upgrade_region_domain is not None:
            pulumi.set(__self__, "upgrade_region_domain", upgrade_region_domain)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Input[builtins.str]:
        """
        弹性公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="newAddressPrefix")
    def new_address_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        """
        return pulumi.get(self, "new_address_prefix")

    @new_address_prefix.setter
    def new_address_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_address_prefix", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="upgradeRegionDomain")
    def upgrade_region_domain(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        return pulumi.get(self, "upgrade_region_domain")

    @upgrade_region_domain.setter
    def upgrade_region_domain(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "upgrade_region_domain", value)


@pulumi.input_type
class _EndpointPublicAddressState:
    def __init__(__self__, *,
                 addr_type: Optional[pulumi.Input[builtins.str]] = None,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
                 vi_pv6: Optional[pulumi.Input[builtins.str]] = None,
                 vip: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering EndpointPublicAddress resources.
        :param pulumi.Input[builtins.str] addr_type: 连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        :param pulumi.Input[builtins.str] address: IP 地址或者域名。
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        :param pulumi.Input[builtins.str] vi_pv6: 连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        :param pulumi.Input[builtins.str] vip: 连接地址所对应的 IPv4 地址。
        """
        if addr_type is not None:
            pulumi.set(__self__, "addr_type", addr_type)
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if new_address_prefix is not None:
            pulumi.set(__self__, "new_address_prefix", new_address_prefix)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if upgrade_region_domain is not None:
            pulumi.set(__self__, "upgrade_region_domain", upgrade_region_domain)
        if vi_pv6 is not None:
            pulumi.set(__self__, "vi_pv6", vi_pv6)
        if vip is not None:
            pulumi.set(__self__, "vip", vip)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        """
        return pulumi.get(self, "addr_type")

    @addr_type.setter
    def addr_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "addr_type", value)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        弹性公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="newAddressPrefix")
    def new_address_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        """
        return pulumi.get(self, "new_address_prefix")

    @new_address_prefix.setter
    def new_address_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_address_prefix", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="upgradeRegionDomain")
    def upgrade_region_domain(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        return pulumi.get(self, "upgrade_region_domain")

    @upgrade_region_domain.setter
    def upgrade_region_domain(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "upgrade_region_domain", value)

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        """
        return pulumi.get(self, "vi_pv6")

    @vi_pv6.setter
    def vi_pv6(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vi_pv6", value)

    @property
    @pulumi.getter
    def vip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")

    @vip.setter
    def vip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vip", value)


@pulumi.type_token("bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress")
class EndpointPublicAddress(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        开启公网访问，以便 VPC 外的设备来访问 Redis 实例。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        redis_endpoint_public_address_demo = bytepluscc.redis.EndpointPublicAddress("RedisEndpointPublicAddressDemo",
            instance_id="redis-cnlfii2cw1xxxxxx",
            port=6379,
            eip_id="eip-w08rcc38bsw0865yxxxxx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress example "instance_id|eip_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointPublicAddressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        开启公网访问，以便 VPC 外的设备来访问 Redis 实例。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        redis_endpoint_public_address_demo = bytepluscc.redis.EndpointPublicAddress("RedisEndpointPublicAddressDemo",
            instance_id="redis-cnlfii2cw1xxxxxx",
            port=6379,
            eip_id="eip-w08rcc38bsw0865yxxxxx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress example "instance_id|eip_id"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointPublicAddressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointPublicAddressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointPublicAddressArgs.__new__(EndpointPublicAddressArgs)

            if eip_id is None and not opts.urn:
                raise TypeError("Missing required property 'eip_id'")
            __props__.__dict__["eip_id"] = eip_id
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["new_address_prefix"] = new_address_prefix
            __props__.__dict__["port"] = port
            __props__.__dict__["upgrade_region_domain"] = upgrade_region_domain
            __props__.__dict__["addr_type"] = None
            __props__.__dict__["address"] = None
            __props__.__dict__["vi_pv6"] = None
            __props__.__dict__["vip"] = None
        super(EndpointPublicAddress, __self__).__init__(
            'bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            addr_type: Optional[pulumi.Input[builtins.str]] = None,
            address: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
            vi_pv6: Optional[pulumi.Input[builtins.str]] = None,
            vip: Optional[pulumi.Input[builtins.str]] = None) -> 'EndpointPublicAddress':
        """
        Get an existing EndpointPublicAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] addr_type: 连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        :param pulumi.Input[builtins.str] address: IP 地址或者域名。
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        :param pulumi.Input[builtins.str] vi_pv6: 连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        :param pulumi.Input[builtins.str] vip: 连接地址所对应的 IPv4 地址。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointPublicAddressState.__new__(_EndpointPublicAddressState)

        __props__.__dict__["addr_type"] = addr_type
        __props__.__dict__["address"] = address
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["new_address_prefix"] = new_address_prefix
        __props__.__dict__["port"] = port
        __props__.__dict__["upgrade_region_domain"] = upgrade_region_domain
        __props__.__dict__["vi_pv6"] = vi_pv6
        __props__.__dict__["vip"] = vip
        return EndpointPublicAddress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> pulumi.Output[builtins.str]:
        """
        连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        """
        return pulumi.get(self, "addr_type")

    @property
    @pulumi.getter
    def address(self) -> pulumi.Output[builtins.str]:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        弹性公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="newAddressPrefix")
    def new_address_prefix(self) -> pulumi.Output[builtins.str]:
        """
        修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        """
        return pulumi.get(self, "new_address_prefix")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[builtins.int]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="upgradeRegionDomain")
    def upgrade_region_domain(self) -> pulumi.Output[builtins.bool]:
        """
        是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        return pulumi.get(self, "upgrade_region_domain")

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> pulumi.Output[builtins.str]:
        """
        连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        """
        return pulumi.get(self, "vi_pv6")

    @property
    @pulumi.getter
    def vip(self) -> pulumi.Output[builtins.str]:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")

