# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AllowListArgs', 'AllowList']

@pulumi.input_type
class AllowListArgs:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AllowList resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_list is not None:
            pulumi.set(__self__, "user_allow_list", user_allow_list)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")

    @user_allow_list.setter
    def user_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_allow_list", value)


@pulumi.input_type
class _AllowListState:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AllowList resources.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单中 IP 地址或 IP 地址段的数量。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_id is not None:
            pulumi.set(__self__, "allow_list_id", allow_list_id)
        if allow_list_ip_num is not None:
            pulumi.set(__self__, "allow_list_ip_num", allow_list_ip_num)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if associated_instances is not None:
            pulumi.set(__self__, "associated_instances", associated_instances)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_list is not None:
            pulumi.set(__self__, "user_allow_list", user_allow_list)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单 ID。
        """
        return pulumi.get(self, "allow_list_id")

    @allow_list_id.setter
    def allow_list_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_id", value)

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单中 IP 地址或 IP 地址段的数量。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @allow_list_ip_num.setter
    def allow_list_ip_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_list_ip_num", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]:
        return pulumi.get(self, "associated_instances")

    @associated_instances.setter
    def associated_instances(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]):
        pulumi.set(self, "associated_instances", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")

    @user_allow_list.setter
    def user_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_allow_list", value)


@pulumi.type_token("bytepluscc:rdspostgresql/allowList:AllowList")
class AllowList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。PostgreSQL 实例在创建后，不会绑定任何白名单，默认禁止所有 IP 地址访问实例。因此无论是通过私网还是通过公网连接访问实例，都需要先为实例配置白名单，才能保证实例可连接。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rds_postgresql_allow_list_demo = bytepluscc.rdspostgresql.AllowList("RdsPostgresqlAllowListDemo",
            allow_lists=[
                "1.2.3.4/32",
                "5.6.7.8/32",
            ],
            allow_list_category="Ordinary",
            allow_list_desc="test",
            allow_list_name="ccapi-test-1",
            allow_list_type="IPv4")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdspostgresql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AllowListArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。PostgreSQL 实例在创建后，不会绑定任何白名单，默认禁止所有 IP 地址访问实例。因此无论是通过私网还是通过公网连接访问实例，都需要先为实例配置白名单，才能保证实例可连接。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rds_postgresql_allow_list_demo = bytepluscc.rdspostgresql.AllowList("RdsPostgresqlAllowListDemo",
            allow_lists=[
                "1.2.3.4/32",
                "5.6.7.8/32",
            ],
            allow_list_category="Ordinary",
            allow_list_desc="test",
            allow_list_name="ccapi-test-1",
            allow_list_type="IPv4")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdspostgresql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param AllowListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AllowListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AllowListArgs.__new__(AllowListArgs)

            __props__.__dict__["allow_list_category"] = allow_list_category
            __props__.__dict__["allow_list_desc"] = allow_list_desc
            __props__.__dict__["allow_list_name"] = allow_list_name
            __props__.__dict__["allow_list_type"] = allow_list_type
            __props__.__dict__["allow_lists"] = allow_lists
            __props__.__dict__["associated_instance_num"] = associated_instance_num
            __props__.__dict__["ip_address"] = ip_address
            __props__.__dict__["modify_mode"] = modify_mode
            __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
            __props__.__dict__["update_security_group"] = update_security_group
            __props__.__dict__["user_allow_list"] = user_allow_list
            __props__.__dict__["allow_list_id"] = None
            __props__.__dict__["allow_list_ip_num"] = None
            __props__.__dict__["associated_instances"] = None
        super(AllowList, __self__).__init__(
            'bytepluscc:rdspostgresql/allowList:AllowList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
            allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
            allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
            associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListAssociatedInstanceArgs', 'AllowListAssociatedInstanceArgsDict']]]]] = None,
            ip_address: Optional[pulumi.Input[builtins.str]] = None,
            modify_mode: Optional[pulumi.Input[builtins.str]] = None,
            security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
            update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
            user_allow_list: Optional[pulumi.Input[builtins.str]] = None) -> 'AllowList':
        """
        Get an existing AllowList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单中 IP 地址或 IP 地址段的数量。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AllowListState.__new__(_AllowListState)

        __props__.__dict__["allow_list_category"] = allow_list_category
        __props__.__dict__["allow_list_desc"] = allow_list_desc
        __props__.__dict__["allow_list_id"] = allow_list_id
        __props__.__dict__["allow_list_ip_num"] = allow_list_ip_num
        __props__.__dict__["allow_list_name"] = allow_list_name
        __props__.__dict__["allow_list_type"] = allow_list_type
        __props__.__dict__["allow_lists"] = allow_lists
        __props__.__dict__["associated_instance_num"] = associated_instance_num
        __props__.__dict__["associated_instances"] = associated_instances
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["modify_mode"] = modify_mode
        __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
        __props__.__dict__["update_security_group"] = update_security_group
        __props__.__dict__["user_allow_list"] = user_allow_list
        return AllowList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> pulumi.Output[builtins.str]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> pulumi.Output[builtins.str]:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> pulumi.Output[builtins.str]:
        """
        白名单 ID。
        """
        return pulumi.get(self, "allow_list_id")

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> pulumi.Output[builtins.int]:
        """
        白名单中 IP 地址或 IP 地址段的数量。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> pulumi.Output[builtins.str]:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> pulumi.Output[builtins.str]:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> pulumi.Output[builtins.int]:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> pulumi.Output[Sequence['outputs.AllowListAssociatedInstance']]:
        return pulumi.get(self, "associated_instances")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[builtins.str]:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> pulumi.Output[builtins.str]:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> pulumi.Output[Sequence['outputs.AllowListSecurityGroupBindInfo']]:
        return pulumi.get(self, "security_group_bind_infos")

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> pulumi.Output[builtins.bool]:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> pulumi.Output[builtins.str]:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")

