# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EndpointArgs', 'Endpoint']

@pulumi.input_type
class EndpointArgs:
    def __init__(__self__, *,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Endpoint resource.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if auto_add_new_nodes is not None:
            pulumi.set(__self__, "auto_add_new_nodes", auto_add_new_nodes)
        if connect_all_slave_nodes is not None:
            pulumi.set(__self__, "connect_all_slave_nodes", connect_all_slave_nodes)
        if connection_mode is not None:
            pulumi.set(__self__, "connection_mode", connection_mode)
        if connection_pool_type is not None:
            pulumi.set(__self__, "connection_pool_type", connection_pool_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_connection_persistent is not None:
            pulumi.set(__self__, "enable_connection_persistent", enable_connection_persistent)
        if endpoint_name is not None:
            pulumi.set(__self__, "endpoint_name", endpoint_name)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if idle_connection_reclaim is not None:
            pulumi.set(__self__, "idle_connection_reclaim", idle_connection_reclaim)
        if implicit_trans_split is not None:
            pulumi.set(__self__, "implicit_trans_split", implicit_trans_split)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if master_node_routing is not None:
            pulumi.set(__self__, "master_node_routing", master_node_routing)
        if master_protector_timeout is not None:
            pulumi.set(__self__, "master_protector_timeout", master_protector_timeout)
        if multi_statements_mode is not None:
            pulumi.set(__self__, "multi_statements_mode", multi_statements_mode)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if overload_protection is not None:
            pulumi.set(__self__, "overload_protection", overload_protection)
        if read_only_node_distribution_type is not None:
            pulumi.set(__self__, "read_only_node_distribution_type", read_only_node_distribution_type)
        if read_only_node_max_delay_time is not None:
            pulumi.set(__self__, "read_only_node_max_delay_time", read_only_node_max_delay_time)
        if read_only_node_weights is not None:
            pulumi.set(__self__, "read_only_node_weights", read_only_node_weights)
        if read_write_mode is not None:
            pulumi.set(__self__, "read_write_mode", read_write_mode)
        if read_write_spliting is not None:
            pulumi.set(__self__, "read_write_spliting", read_write_spliting)

    @property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]:
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]):
        pulumi.set(self, "addresses", value)

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @auto_add_new_nodes.setter
    def auto_add_new_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_add_new_nodes", value)

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @connect_all_slave_nodes.setter
    def connect_all_slave_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "connect_all_slave_nodes", value)

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @connection_mode.setter
    def connection_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_mode", value)

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @connection_pool_type.setter
    def connection_pool_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_pool_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @enable_connection_persistent.setter
    def enable_connection_persistent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_connection_persistent", value)

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @endpoint_name.setter
    def endpoint_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_name", value)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @idle_connection_reclaim.setter
    def idle_connection_reclaim(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "idle_connection_reclaim", value)

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @implicit_trans_split.setter
    def implicit_trans_split(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "implicit_trans_split", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @master_node_routing.setter
    def master_node_routing(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "master_node_routing", value)

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @master_protector_timeout.setter
    def master_protector_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "master_protector_timeout", value)

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @multi_statements_mode.setter
    def multi_statements_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_statements_mode", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @overload_protection.setter
    def overload_protection(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overload_protection", value)

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @read_only_node_distribution_type.setter
    def read_only_node_distribution_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_only_node_distribution_type", value)

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @read_only_node_max_delay_time.setter
    def read_only_node_max_delay_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_only_node_max_delay_time", value)

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]:
        return pulumi.get(self, "read_only_node_weights")

    @read_only_node_weights.setter
    def read_only_node_weights(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]):
        pulumi.set(self, "read_only_node_weights", value)

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @read_write_mode.setter
    def read_write_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_write_mode", value)

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")

    @read_write_spliting.setter
    def read_write_spliting(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_write_spliting", value)


@pulumi.input_type
class _EndpointState:
    def __init__(__self__, *,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_info_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 custom_route_strategy: Optional[pulumi.Input['EndpointCustomRouteStrategyArgs']] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_read_only: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Endpoint resources.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] connection_info_tags: 连接终端标签。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input['EndpointCustomRouteStrategyArgs'] custom_route_strategy: 连接终端的 SQL 转发规则。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] enable_read_only: 是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        :param pulumi.Input[builtins.str] endpoint_id: 实例连接终端 ID。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if auto_add_new_nodes is not None:
            pulumi.set(__self__, "auto_add_new_nodes", auto_add_new_nodes)
        if connect_all_slave_nodes is not None:
            pulumi.set(__self__, "connect_all_slave_nodes", connect_all_slave_nodes)
        if connection_info_tags is not None:
            pulumi.set(__self__, "connection_info_tags", connection_info_tags)
        if connection_mode is not None:
            pulumi.set(__self__, "connection_mode", connection_mode)
        if connection_pool_type is not None:
            pulumi.set(__self__, "connection_pool_type", connection_pool_type)
        if custom_route_strategy is not None:
            pulumi.set(__self__, "custom_route_strategy", custom_route_strategy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_connection_persistent is not None:
            pulumi.set(__self__, "enable_connection_persistent", enable_connection_persistent)
        if enable_read_only is not None:
            pulumi.set(__self__, "enable_read_only", enable_read_only)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_name is not None:
            pulumi.set(__self__, "endpoint_name", endpoint_name)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if idle_connection_reclaim is not None:
            pulumi.set(__self__, "idle_connection_reclaim", idle_connection_reclaim)
        if implicit_trans_split is not None:
            pulumi.set(__self__, "implicit_trans_split", implicit_trans_split)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if master_node_routing is not None:
            pulumi.set(__self__, "master_node_routing", master_node_routing)
        if master_protector_timeout is not None:
            pulumi.set(__self__, "master_protector_timeout", master_protector_timeout)
        if multi_statements_mode is not None:
            pulumi.set(__self__, "multi_statements_mode", multi_statements_mode)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if overload_protection is not None:
            pulumi.set(__self__, "overload_protection", overload_protection)
        if read_only_node_distribution_type is not None:
            pulumi.set(__self__, "read_only_node_distribution_type", read_only_node_distribution_type)
        if read_only_node_max_delay_time is not None:
            pulumi.set(__self__, "read_only_node_max_delay_time", read_only_node_max_delay_time)
        if read_only_node_weights is not None:
            pulumi.set(__self__, "read_only_node_weights", read_only_node_weights)
        if read_write_mode is not None:
            pulumi.set(__self__, "read_write_mode", read_write_mode)
        if read_write_spliting is not None:
            pulumi.set(__self__, "read_write_spliting", read_write_spliting)

    @property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]:
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]):
        pulumi.set(self, "addresses", value)

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @auto_add_new_nodes.setter
    def auto_add_new_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_add_new_nodes", value)

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @connect_all_slave_nodes.setter
    def connect_all_slave_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "connect_all_slave_nodes", value)

    @property
    @pulumi.getter(name="connectionInfoTags")
    def connection_info_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        连接终端标签。
        """
        return pulumi.get(self, "connection_info_tags")

    @connection_info_tags.setter
    def connection_info_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "connection_info_tags", value)

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @connection_mode.setter
    def connection_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_mode", value)

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @connection_pool_type.setter
    def connection_pool_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_pool_type", value)

    @property
    @pulumi.getter(name="customRouteStrategy")
    def custom_route_strategy(self) -> Optional[pulumi.Input['EndpointCustomRouteStrategyArgs']]:
        """
        连接终端的 SQL 转发规则。
        """
        return pulumi.get(self, "custom_route_strategy")

    @custom_route_strategy.setter
    def custom_route_strategy(self, value: Optional[pulumi.Input['EndpointCustomRouteStrategyArgs']]):
        pulumi.set(self, "custom_route_strategy", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @enable_connection_persistent.setter
    def enable_connection_persistent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_connection_persistent", value)

    @property
    @pulumi.getter(name="enableReadOnly")
    def enable_read_only(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        """
        return pulumi.get(self, "enable_read_only")

    @enable_read_only.setter
    def enable_read_only(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_read_only", value)

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例连接终端 ID。
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @endpoint_name.setter
    def endpoint_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_name", value)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @idle_connection_reclaim.setter
    def idle_connection_reclaim(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "idle_connection_reclaim", value)

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @implicit_trans_split.setter
    def implicit_trans_split(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "implicit_trans_split", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @master_node_routing.setter
    def master_node_routing(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "master_node_routing", value)

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @master_protector_timeout.setter
    def master_protector_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "master_protector_timeout", value)

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @multi_statements_mode.setter
    def multi_statements_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_statements_mode", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @overload_protection.setter
    def overload_protection(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overload_protection", value)

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @read_only_node_distribution_type.setter
    def read_only_node_distribution_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_only_node_distribution_type", value)

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @read_only_node_max_delay_time.setter
    def read_only_node_max_delay_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_only_node_max_delay_time", value)

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]:
        return pulumi.get(self, "read_only_node_weights")

    @read_only_node_weights.setter
    def read_only_node_weights(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]):
        pulumi.set(self, "read_only_node_weights", value)

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @read_write_mode.setter
    def read_write_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_write_mode", value)

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")

    @read_write_spliting.setter
    def read_write_spliting(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_write_spliting", value)


@pulumi.type_token("bytepluscc:rdsmysql/endpoint:Endpoint")
class Endpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointAddressArgs', 'EndpointAddressArgsDict']]]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointReadOnlyNodeWeightArgs', 'EndpointReadOnlyNodeWeightArgsDict']]]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        连接终端是云数据库 MySQL 版提供的位于数据库和应用程序之间的网络代理服务。根据连接终端的功能差异，连接终端可以分为代理终端和直连终端两种类型。通过代理终端的连接将经过代理，可使用代理相关的特性和功能，如读写分离、负载均衡、空闲连接回收和 Multi-Statements 等；通过直连终端的连接将直连到对应节点，不能使用代理相关特性。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/endpoint:Endpoint example "instance_id|endpoint_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EndpointArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        连接终端是云数据库 MySQL 版提供的位于数据库和应用程序之间的网络代理服务。根据连接终端的功能差异，连接终端可以分为代理终端和直连终端两种类型。通过代理终端的连接将经过代理，可使用代理相关的特性和功能，如读写分离、负载均衡、空闲连接回收和 Multi-Statements 等；通过直连终端的连接将直连到对应节点，不能使用代理相关特性。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/endpoint:Endpoint example "instance_id|endpoint_id"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointAddressArgs', 'EndpointAddressArgsDict']]]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointReadOnlyNodeWeightArgs', 'EndpointReadOnlyNodeWeightArgsDict']]]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointArgs.__new__(EndpointArgs)

            __props__.__dict__["addresses"] = addresses
            __props__.__dict__["auto_add_new_nodes"] = auto_add_new_nodes
            __props__.__dict__["connect_all_slave_nodes"] = connect_all_slave_nodes
            __props__.__dict__["connection_mode"] = connection_mode
            __props__.__dict__["connection_pool_type"] = connection_pool_type
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_connection_persistent"] = enable_connection_persistent
            __props__.__dict__["endpoint_name"] = endpoint_name
            __props__.__dict__["endpoint_type"] = endpoint_type
            __props__.__dict__["idle_connection_reclaim"] = idle_connection_reclaim
            __props__.__dict__["implicit_trans_split"] = implicit_trans_split
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["master_node_routing"] = master_node_routing
            __props__.__dict__["master_protector_timeout"] = master_protector_timeout
            __props__.__dict__["multi_statements_mode"] = multi_statements_mode
            __props__.__dict__["nodes"] = nodes
            __props__.__dict__["overload_protection"] = overload_protection
            __props__.__dict__["read_only_node_distribution_type"] = read_only_node_distribution_type
            __props__.__dict__["read_only_node_max_delay_time"] = read_only_node_max_delay_time
            __props__.__dict__["read_only_node_weights"] = read_only_node_weights
            __props__.__dict__["read_write_mode"] = read_write_mode
            __props__.__dict__["read_write_spliting"] = read_write_spliting
            __props__.__dict__["connection_info_tags"] = None
            __props__.__dict__["custom_route_strategy"] = None
            __props__.__dict__["enable_read_only"] = None
            __props__.__dict__["endpoint_id"] = None
        super(Endpoint, __self__).__init__(
            'bytepluscc:rdsmysql/endpoint:Endpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointAddressArgs', 'EndpointAddressArgsDict']]]]] = None,
            auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
            connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
            connection_info_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            connection_mode: Optional[pulumi.Input[builtins.str]] = None,
            connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
            custom_route_strategy: Optional[pulumi.Input[Union['EndpointCustomRouteStrategyArgs', 'EndpointCustomRouteStrategyArgsDict']]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
            enable_read_only: Optional[pulumi.Input[builtins.str]] = None,
            endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
            endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
            endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
            idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
            implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
            master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
            multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
            nodes: Optional[pulumi.Input[builtins.str]] = None,
            overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
            read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
            read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
            read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointReadOnlyNodeWeightArgs', 'EndpointReadOnlyNodeWeightArgsDict']]]]] = None,
            read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
            read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None) -> 'Endpoint':
        """
        Get an existing Endpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] connection_info_tags: 连接终端标签。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input[Union['EndpointCustomRouteStrategyArgs', 'EndpointCustomRouteStrategyArgsDict']] custom_route_strategy: 连接终端的 SQL 转发规则。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] enable_read_only: 是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        :param pulumi.Input[builtins.str] endpoint_id: 实例连接终端 ID。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointState.__new__(_EndpointState)

        __props__.__dict__["addresses"] = addresses
        __props__.__dict__["auto_add_new_nodes"] = auto_add_new_nodes
        __props__.__dict__["connect_all_slave_nodes"] = connect_all_slave_nodes
        __props__.__dict__["connection_info_tags"] = connection_info_tags
        __props__.__dict__["connection_mode"] = connection_mode
        __props__.__dict__["connection_pool_type"] = connection_pool_type
        __props__.__dict__["custom_route_strategy"] = custom_route_strategy
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_connection_persistent"] = enable_connection_persistent
        __props__.__dict__["enable_read_only"] = enable_read_only
        __props__.__dict__["endpoint_id"] = endpoint_id
        __props__.__dict__["endpoint_name"] = endpoint_name
        __props__.__dict__["endpoint_type"] = endpoint_type
        __props__.__dict__["idle_connection_reclaim"] = idle_connection_reclaim
        __props__.__dict__["implicit_trans_split"] = implicit_trans_split
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["master_node_routing"] = master_node_routing
        __props__.__dict__["master_protector_timeout"] = master_protector_timeout
        __props__.__dict__["multi_statements_mode"] = multi_statements_mode
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["overload_protection"] = overload_protection
        __props__.__dict__["read_only_node_distribution_type"] = read_only_node_distribution_type
        __props__.__dict__["read_only_node_max_delay_time"] = read_only_node_max_delay_time
        __props__.__dict__["read_only_node_weights"] = read_only_node_weights
        __props__.__dict__["read_write_mode"] = read_write_mode
        __props__.__dict__["read_write_spliting"] = read_write_spliting
        return Endpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def addresses(self) -> pulumi.Output[Sequence['outputs.EndpointAddress']]:
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> pulumi.Output[builtins.bool]:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> pulumi.Output[builtins.bool]:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @property
    @pulumi.getter(name="connectionInfoTags")
    def connection_info_tags(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        连接终端标签。
        """
        return pulumi.get(self, "connection_info_tags")

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> pulumi.Output[builtins.str]:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> pulumi.Output[builtins.str]:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @property
    @pulumi.getter(name="customRouteStrategy")
    def custom_route_strategy(self) -> pulumi.Output['outputs.EndpointCustomRouteStrategy']:
        """
        连接终端的 SQL 转发规则。
        """
        return pulumi.get(self, "custom_route_strategy")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @property
    @pulumi.getter(name="enableReadOnly")
    def enable_read_only(self) -> pulumi.Output[builtins.str]:
        """
        是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        """
        return pulumi.get(self, "enable_read_only")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> pulumi.Output[builtins.str]:
        """
        实例连接终端 ID。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> pulumi.Output[builtins.str]:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> pulumi.Output[builtins.str]:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> pulumi.Output[builtins.bool]:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> pulumi.Output[builtins.int]:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> pulumi.Output[builtins.str]:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[builtins.str]:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> pulumi.Output[builtins.str]:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> pulumi.Output[builtins.int]:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> pulumi.Output[Sequence['outputs.EndpointReadOnlyNodeWeight']]:
        return pulumi.get(self, "read_only_node_weights")

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> pulumi.Output[builtins.str]:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")

