# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MountPointArgs', 'MountPoint']

@pulumi.input_type
class MountPointArgs:
    def __init__(__self__, *,
                 file_system_id: pulumi.Input[builtins.str],
                 mount_point_name: pulumi.Input[builtins.str],
                 permission_group_id: pulumi.Input[builtins.str],
                 subnet_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a MountPoint resource.
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        """
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "mount_point_name", mount_point_name)
        pulumi.set(__self__, "permission_group_id", permission_group_id)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[builtins.str]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> pulumi.Input[builtins.str]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mount_point_name", value)

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> pulumi.Input[builtins.str]:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @permission_group_id.setter
    def permission_group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "permission_group_id", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)


@pulumi.input_type
class _MountPointState:
    def __init__(__self__, *,
                 clients: Optional[pulumi.Input[Sequence[pulumi.Input['MountPointClientArgs']]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_group: Optional[pulumi.Input['MountPointPermissionGroupArgs']] = None,
                 permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering MountPoint resources.
        :param pulumi.Input[builtins.str] created_time: 挂载点创建时间。
        :param pulumi.Input[builtins.str] domain: DNS 地址。
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] ip: 挂载点地址。
        :param pulumi.Input[builtins.str] mount_point_id: 挂载点 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input['MountPointPermissionGroupArgs'] permission_group: 挂载点绑定的权限组信息。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] status: 挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] subnet_name: 子网名称。
        :param pulumi.Input[builtins.str] updated_time: 挂载点更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.str] vpc_name: 私有网络名称。
        """
        if clients is not None:
            pulumi.set(__self__, "clients", clients)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if mount_point_id is not None:
            pulumi.set(__self__, "mount_point_id", mount_point_id)
        if mount_point_name is not None:
            pulumi.set(__self__, "mount_point_name", mount_point_name)
        if permission_group is not None:
            pulumi.set(__self__, "permission_group", permission_group)
        if permission_group_id is not None:
            pulumi.set(__self__, "permission_group_id", permission_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if subnet_name is not None:
            pulumi.set(__self__, "subnet_name", subnet_name)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter
    def clients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MountPointClientArgs']]]]:
        return pulumi.get(self, "clients")

    @clients.setter
    def clients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MountPointClientArgs']]]]):
        pulumi.set(self, "clients", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNS 地址。
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点地址。
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @mount_point_id.setter
    def mount_point_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mount_point_id", value)

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mount_point_name", value)

    @property
    @pulumi.getter(name="permissionGroup")
    def permission_group(self) -> Optional[pulumi.Input['MountPointPermissionGroupArgs']]:
        """
        挂载点绑定的权限组信息。
        """
        return pulumi.get(self, "permission_group")

    @permission_group.setter
    def permission_group(self, value: Optional[pulumi.Input['MountPointPermissionGroupArgs']]):
        pulumi.set(self, "permission_group", value)

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @permission_group_id.setter
    def permission_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网名称。
        """
        return pulumi.get(self, "subnet_name")

    @subnet_name.setter
    def subnet_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_name", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)


@pulumi.type_token("bytepluscc:filenas/mountPoint:MountPoint")
class MountPoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        挂载点是 NAS 文件系统在网络环境中的连接点。NAS 文件系统需要挂载在计算节点中才能完成数据的访问与存储。挂载是将计算节点与 NAS 文件系统相连接的操作。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        file_nas_mount_point_demo = bytepluscc.filenas.MountPoint("FileNASMountPointDemo",
            file_system_id="enas-cnbja0f8*****",
            mount_point_name="test-1",
            permission_group_id="pgroup-01bc1182",
            subnet_id="subnet-btepcsc5*****",
            vpc_id="vpc-3nr6adcn064u8931*****")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:filenas/mountPoint:MountPoint example "file_system_id|mount_point_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MountPointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        挂载点是 NAS 文件系统在网络环境中的连接点。NAS 文件系统需要挂载在计算节点中才能完成数据的访问与存储。挂载是将计算节点与 NAS 文件系统相连接的操作。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        file_nas_mount_point_demo = bytepluscc.filenas.MountPoint("FileNASMountPointDemo",
            file_system_id="enas-cnbja0f8*****",
            mount_point_name="test-1",
            permission_group_id="pgroup-01bc1182",
            subnet_id="subnet-btepcsc5*****",
            vpc_id="vpc-3nr6adcn064u8931*****")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:filenas/mountPoint:MountPoint example "file_system_id|mount_point_id"
        ```

        :param str resource_name: The name of the resource.
        :param MountPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MountPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MountPointArgs.__new__(MountPointArgs)

            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            if mount_point_name is None and not opts.urn:
                raise TypeError("Missing required property 'mount_point_name'")
            __props__.__dict__["mount_point_name"] = mount_point_name
            if permission_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'permission_group_id'")
            __props__.__dict__["permission_group_id"] = permission_group_id
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["clients"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["domain"] = None
            __props__.__dict__["ip"] = None
            __props__.__dict__["mount_point_id"] = None
            __props__.__dict__["permission_group"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["subnet_name"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["vpc_name"] = None
        super(MountPoint, __self__).__init__(
            'bytepluscc:filenas/mountPoint:MountPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            clients: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MountPointClientArgs', 'MountPointClientArgsDict']]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            file_system_id: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            mount_point_id: Optional[pulumi.Input[builtins.str]] = None,
            mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
            permission_group: Optional[pulumi.Input[Union['MountPointPermissionGroupArgs', 'MountPointPermissionGroupArgsDict']]] = None,
            permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            subnet_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpc_name: Optional[pulumi.Input[builtins.str]] = None) -> 'MountPoint':
        """
        Get an existing MountPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 挂载点创建时间。
        :param pulumi.Input[builtins.str] domain: DNS 地址。
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] ip: 挂载点地址。
        :param pulumi.Input[builtins.str] mount_point_id: 挂载点 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input[Union['MountPointPermissionGroupArgs', 'MountPointPermissionGroupArgsDict']] permission_group: 挂载点绑定的权限组信息。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] status: 挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] subnet_name: 子网名称。
        :param pulumi.Input[builtins.str] updated_time: 挂载点更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.str] vpc_name: 私有网络名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MountPointState.__new__(_MountPointState)

        __props__.__dict__["clients"] = clients
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["domain"] = domain
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["ip"] = ip
        __props__.__dict__["mount_point_id"] = mount_point_id
        __props__.__dict__["mount_point_name"] = mount_point_name
        __props__.__dict__["permission_group"] = permission_group
        __props__.__dict__["permission_group_id"] = permission_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["subnet_name"] = subnet_name
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        return MountPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def clients(self) -> pulumi.Output[Sequence['outputs.MountPointClient']]:
        return pulumi.get(self, "clients")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        挂载点创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        DNS 地址。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[builtins.str]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        挂载点地址。
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> pulumi.Output[builtins.str]:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> pulumi.Output[builtins.str]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @property
    @pulumi.getter(name="permissionGroup")
    def permission_group(self) -> pulumi.Output['outputs.MountPointPermissionGroup']:
        """
        挂载点绑定的权限组信息。
        """
        return pulumi.get(self, "permission_group")

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> pulumi.Output[builtins.str]:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> pulumi.Output[builtins.str]:
        """
        子网名称。
        """
        return pulumi.get(self, "subnet_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        挂载点更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[builtins.str]:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

