# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCustomizedCfgResult',
    'AwaitableGetCustomizedCfgResult',
    'get_customized_cfg',
    'get_customized_cfg_output',
]

@pulumi.output_type
class GetCustomizedCfgResult:
    """
    A collection of values returned by getCustomizedCfg.
    """
    def __init__(__self__, created_time=None, customized_cfg_content=None, customized_cfg_id=None, customized_cfg_name=None, description=None, id=None, listeners=None, project_name=None, status=None, tags=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if customized_cfg_content and not isinstance(customized_cfg_content, str):
            raise TypeError("Expected argument 'customized_cfg_content' to be a str")
        pulumi.set(__self__, "customized_cfg_content", customized_cfg_content)
        if customized_cfg_id and not isinstance(customized_cfg_id, str):
            raise TypeError("Expected argument 'customized_cfg_id' to be a str")
        pulumi.set(__self__, "customized_cfg_id", customized_cfg_id)
        if customized_cfg_name and not isinstance(customized_cfg_name, str):
            raise TypeError("Expected argument 'customized_cfg_name' to be a str")
        pulumi.set(__self__, "customized_cfg_name", customized_cfg_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listeners and not isinstance(listeners, list):
            raise TypeError("Expected argument 'listeners' to be a list")
        pulumi.set(__self__, "listeners", listeners)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        个性化配置的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> builtins.str:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> builtins.str:
        """
        个性化配置的 ID 。
        """
        return pulumi.get(self, "customized_cfg_id")

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> builtins.str:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def listeners(self) -> Sequence['outputs.GetCustomizedCfgListenerResult']:
        """
        个性化配置关联的监听器列表。
        """
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetCustomizedCfgTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        个性化配置的最近操作时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetCustomizedCfgResult(GetCustomizedCfgResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCustomizedCfgResult(
            created_time=self.created_time,
            customized_cfg_content=self.customized_cfg_content,
            customized_cfg_id=self.customized_cfg_id,
            customized_cfg_name=self.customized_cfg_name,
            description=self.description,
            id=self.id,
            listeners=self.listeners,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_customized_cfg(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCustomizedCfgResult:
    """
    Data Source schema for Byteplus::ALB::CustomizedCfg


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:alb/getCustomizedCfg:getCustomizedCfg', __args__, opts=opts, typ=GetCustomizedCfgResult).value

    return AwaitableGetCustomizedCfgResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        customized_cfg_content=pulumi.get(__ret__, 'customized_cfg_content'),
        customized_cfg_id=pulumi.get(__ret__, 'customized_cfg_id'),
        customized_cfg_name=pulumi.get(__ret__, 'customized_cfg_name'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        listeners=pulumi.get(__ret__, 'listeners'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_customized_cfg_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCustomizedCfgResult]:
    """
    Data Source schema for Byteplus::ALB::CustomizedCfg


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:alb/getCustomizedCfg:getCustomizedCfg', __args__, opts=opts, typ=GetCustomizedCfgResult)
    return __ret__.apply(lambda __response__: GetCustomizedCfgResult(
        created_time=pulumi.get(__response__, 'created_time'),
        customized_cfg_content=pulumi.get(__response__, 'customized_cfg_content'),
        customized_cfg_id=pulumi.get(__response__, 'customized_cfg_id'),
        customized_cfg_name=pulumi.get(__response__, 'customized_cfg_name'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        listeners=pulumi.get(__response__, 'listeners'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))
