# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetHaVipResult',
    'AwaitableGetHaVipResult',
    'get_ha_vip',
    'get_ha_vip_output',
]

@pulumi.output_type
class GetHaVipResult:
    """
    A collection of values returned by getHaVip.
    """
    def __init__(__self__, associated_eip_address=None, associated_eip_id=None, associated_instance_ids=None, associated_instance_type=None, created_at=None, description=None, ha_vip_id=None, ha_vip_name=None, id=None, ip_address=None, master_instance_id=None, project_name=None, status=None, subnet_id=None, tags=None, updated_at=None, vpc_id=None):
        if associated_eip_address and not isinstance(associated_eip_address, str):
            raise TypeError("Expected argument 'associated_eip_address' to be a str")
        pulumi.set(__self__, "associated_eip_address", associated_eip_address)
        if associated_eip_id and not isinstance(associated_eip_id, str):
            raise TypeError("Expected argument 'associated_eip_id' to be a str")
        pulumi.set(__self__, "associated_eip_id", associated_eip_id)
        if associated_instance_ids and not isinstance(associated_instance_ids, list):
            raise TypeError("Expected argument 'associated_instance_ids' to be a list")
        pulumi.set(__self__, "associated_instance_ids", associated_instance_ids)
        if associated_instance_type and not isinstance(associated_instance_type, str):
            raise TypeError("Expected argument 'associated_instance_type' to be a str")
        pulumi.set(__self__, "associated_instance_type", associated_instance_type)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if ha_vip_id and not isinstance(ha_vip_id, str):
            raise TypeError("Expected argument 'ha_vip_id' to be a str")
        pulumi.set(__self__, "ha_vip_id", ha_vip_id)
        if ha_vip_name and not isinstance(ha_vip_name, str):
            raise TypeError("Expected argument 'ha_vip_name' to be a str")
        pulumi.set(__self__, "ha_vip_name", ha_vip_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if master_instance_id and not isinstance(master_instance_id, str):
            raise TypeError("Expected argument 'master_instance_id' to be a str")
        pulumi.set(__self__, "master_instance_id", master_instance_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="associatedEipAddress")
    def associated_eip_address(self) -> builtins.str:
        """
        HAVIP绑定的公网IP的IP地址。
        """
        return pulumi.get(self, "associated_eip_address")

    @property
    @pulumi.getter(name="associatedEipId")
    def associated_eip_id(self) -> builtins.str:
        """
        HAVIP绑定的公网IP的ID。
        """
        return pulumi.get(self, "associated_eip_id")

    @property
    @pulumi.getter(name="associatedInstanceIds")
    def associated_instance_ids(self) -> Sequence[builtins.str]:
        """
        绑定HAVIP的实例ID列表。
        """
        return pulumi.get(self, "associated_instance_ids")

    @property
    @pulumi.getter(name="associatedInstanceType")
    def associated_instance_type(self) -> builtins.str:
        """
        绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        """
        return pulumi.get(self, "associated_instance_type")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        HAVIP的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        HAVIP的描述。长度限制为0～255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="haVipId")
    def ha_vip_id(self) -> builtins.str:
        """
        HAVIP的ID。
        """
        return pulumi.get(self, "ha_vip_id")

    @property
    @pulumi.getter(name="haVipName")
    def ha_vip_name(self) -> builtins.str:
        """
        HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        """
        return pulumi.get(self, "ha_vip_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> builtins.str:
        """
        HAVIP的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> builtins.str:
        """
        与HAVIP绑定的主实例的ID。
        """
        return pulumi.get(self, "master_instance_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        HAVIP的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        HAVIP的状态。Available：可用。Creating：创建中。InUse：使用中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        HAVIP所属的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetHaVipTagResult']:
        """
        HAVIP所属标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        HAVIP最近一次的修改时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        HAVIP所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetHaVipResult(GetHaVipResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHaVipResult(
            associated_eip_address=self.associated_eip_address,
            associated_eip_id=self.associated_eip_id,
            associated_instance_ids=self.associated_instance_ids,
            associated_instance_type=self.associated_instance_type,
            created_at=self.created_at,
            description=self.description,
            ha_vip_id=self.ha_vip_id,
            ha_vip_name=self.ha_vip_name,
            id=self.id,
            ip_address=self.ip_address,
            master_instance_id=self.master_instance_id,
            project_name=self.project_name,
            status=self.status,
            subnet_id=self.subnet_id,
            tags=self.tags,
            updated_at=self.updated_at,
            vpc_id=self.vpc_id)


def get_ha_vip(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHaVipResult:
    """
    Data Source schema for Byteplus::VPC::HAVIP


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getHaVip:getHaVip', __args__, opts=opts, typ=GetHaVipResult).value

    return AwaitableGetHaVipResult(
        associated_eip_address=pulumi.get(__ret__, 'associated_eip_address'),
        associated_eip_id=pulumi.get(__ret__, 'associated_eip_id'),
        associated_instance_ids=pulumi.get(__ret__, 'associated_instance_ids'),
        associated_instance_type=pulumi.get(__ret__, 'associated_instance_type'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        ha_vip_id=pulumi.get(__ret__, 'ha_vip_id'),
        ha_vip_name=pulumi.get(__ret__, 'ha_vip_name'),
        id=pulumi.get(__ret__, 'id'),
        ip_address=pulumi.get(__ret__, 'ip_address'),
        master_instance_id=pulumi.get(__ret__, 'master_instance_id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_ha_vip_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetHaVipResult]:
    """
    Data Source schema for Byteplus::VPC::HAVIP


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getHaVip:getHaVip', __args__, opts=opts, typ=GetHaVipResult)
    return __ret__.apply(lambda __response__: GetHaVipResult(
        associated_eip_address=pulumi.get(__response__, 'associated_eip_address'),
        associated_eip_id=pulumi.get(__response__, 'associated_eip_id'),
        associated_instance_ids=pulumi.get(__response__, 'associated_instance_ids'),
        associated_instance_type=pulumi.get(__response__, 'associated_instance_type'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        ha_vip_id=pulumi.get(__response__, 'ha_vip_id'),
        ha_vip_name=pulumi.get(__response__, 'ha_vip_name'),
        id=pulumi.get(__response__, 'id'),
        ip_address=pulumi.get(__response__, 'ip_address'),
        master_instance_id=pulumi.get(__response__, 'master_instance_id'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))
