# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 compute_spec: pulumi.Input[builtins.str],
                 storage_space: pulumi.Input[builtins.int],
                 subnet_id: pulumi.Input[builtins.str],
                 user_name: pulumi.Input[builtins.str],
                 user_password: pulumi.Input[builtins.str],
                 version: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str],
                 charge_detail: Optional[pulumi.Input['InstanceChargeDetailArgs']] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        :param pulumi.Input['InstanceChargeDetailArgs'] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        """
        pulumi.set(__self__, "compute_spec", compute_spec)
        pulumi.set(__self__, "storage_space", storage_space)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "user_name", user_name)
        pulumi.set(__self__, "user_password", user_password)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if charge_detail is not None:
            pulumi.set(__self__, "charge_detail", charge_detail)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if instance_description is not None:
            pulumi.set(__self__, "instance_description", instance_description)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> pulumi.Input[builtins.str]:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @compute_spec.setter
    def compute_spec(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "compute_spec", value)

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> pulumi.Input[builtins.int]:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @storage_space.setter
    def storage_space(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "storage_space", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[builtins.str]:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> pulumi.Input[builtins.str]:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @user_password.setter
    def user_password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_password", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input[builtins.str]:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> Optional[pulumi.Input['InstanceChargeDetailArgs']]:
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @charge_detail.setter
    def charge_detail(self, value: Optional[pulumi.Input['InstanceChargeDetailArgs']]):
        pulumi.set(self, "charge_detail", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @instance_description.setter
    def instance_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_description", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 apply_private_dns_to_public: Optional[pulumi.Input[builtins.bool]] = None,
                 arch_type: Optional[pulumi.Input[builtins.str]] = None,
                 charge_detail: Optional[pulumi.Input['InstanceChargeDetailArgs']] = None,
                 compute_spec: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_status: Optional[pulumi.Input[builtins.str]] = None,
                 is_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 used_storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_password: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_description: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.str] account_id: 创建实例的主账号ID。
        :param pulumi.Input[builtins.bool] apply_private_dns_to_public: 是否已开启公网解析功能。true：已开启, false：已关闭
        :param pulumi.Input[builtins.str] arch_type: 实例的类型，即集群版或单机版。
        :param pulumi.Input['InstanceChargeDetailArgs'] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_id: RabbitMQ 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] instance_status: 实例状态。
        :param pulumi.Input[builtins.bool] is_encrypted: 是否开启了云盘加密。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.int] used_storage_space: 实例已用存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_description: 可用区的描述信息。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if apply_private_dns_to_public is not None:
            pulumi.set(__self__, "apply_private_dns_to_public", apply_private_dns_to_public)
        if arch_type is not None:
            pulumi.set(__self__, "arch_type", arch_type)
        if charge_detail is not None:
            pulumi.set(__self__, "charge_detail", charge_detail)
        if compute_spec is not None:
            pulumi.set(__self__, "compute_spec", compute_spec)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if instance_description is not None:
            pulumi.set(__self__, "instance_description", instance_description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_status is not None:
            pulumi.set(__self__, "instance_status", instance_status)
        if is_encrypted is not None:
            pulumi.set(__self__, "is_encrypted", is_encrypted)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if storage_space is not None:
            pulumi.set(__self__, "storage_space", storage_space)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if used_storage_space is not None:
            pulumi.set(__self__, "used_storage_space", used_storage_space)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if user_password is not None:
            pulumi.set(__self__, "user_password", user_password)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_description is not None:
            pulumi.set(__self__, "zone_description", zone_description)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建实例的主账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="applyPrivateDnsToPublic")
    def apply_private_dns_to_public(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否已开启公网解析功能。true：已开启, false：已关闭
        """
        return pulumi.get(self, "apply_private_dns_to_public")

    @apply_private_dns_to_public.setter
    def apply_private_dns_to_public(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "apply_private_dns_to_public", value)

    @property
    @pulumi.getter(name="archType")
    def arch_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的类型，即集群版或单机版。
        """
        return pulumi.get(self, "arch_type")

    @arch_type.setter
    def arch_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "arch_type", value)

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> Optional[pulumi.Input['InstanceChargeDetailArgs']]:
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @charge_detail.setter
    def charge_detail(self, value: Optional[pulumi.Input['InstanceChargeDetailArgs']]):
        pulumi.set(self, "charge_detail", value)

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @compute_spec.setter
    def compute_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "compute_spec", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]:
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @instance_description.setter
    def instance_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @instance_status.setter
    def instance_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_status", value)

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启了云盘加密。
        """
        return pulumi.get(self, "is_encrypted")

    @is_encrypted.setter
    def is_encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_encrypted", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @storage_space.setter
    def storage_space(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_space", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="usedStorageSpace")
    def used_storage_space(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例已用存储空间。单位为 GiB。
        """
        return pulumi.get(self, "used_storage_space")

    @used_storage_space.setter
    def used_storage_space(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_storage_space", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @user_password.setter
    def user_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_password", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneDescription")
    def zone_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        可用区的描述信息。
        """
        return pulumi.get(self, "zone_description")

    @zone_description.setter
    def zone_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_description", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:rabbitmq/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
                 compute_spec: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_password: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        消息队列 RabbitMQ版是一款支持 AMQP（Advanced Message Queuing Protocol） 协议的分布式高可用消息队列产品，完全兼容 RabbitMQ 开源生态及多语言客户端，提供丰富的消息特性和灵活的消息路由，同时具备分布式、高吞吐、低延迟、灵活扩展的云消息服务优势，无需用户部署运维，能够轻松实现快速上云。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rabbitmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        消息队列 RabbitMQ版是一款支持 AMQP（Advanced Message Queuing Protocol） 协议的分布式高可用消息队列产品，完全兼容 RabbitMQ 开源生态及多语言客户端，提供丰富的消息特性和灵活的消息路由，同时具备分布式、高吞吐、低延迟、灵活扩展的云消息服务优势，无需用户部署运维，能够轻松实现快速上云。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rabbitmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
                 compute_spec: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_password: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["charge_detail"] = charge_detail
            if compute_spec is None and not opts.urn:
                raise TypeError("Missing required property 'compute_spec'")
            __props__.__dict__["compute_spec"] = compute_spec
            __props__.__dict__["eip_id"] = eip_id
            __props__.__dict__["instance_description"] = instance_description
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["project_name"] = project_name
            if storage_space is None and not opts.urn:
                raise TypeError("Missing required property 'storage_space'")
            __props__.__dict__["storage_space"] = storage_space
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
            if user_password is None and not opts.urn:
                raise TypeError("Missing required property 'user_password'")
            __props__.__dict__["user_password"] = user_password
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["apply_private_dns_to_public"] = None
            __props__.__dict__["arch_type"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["endpoints"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["instance_status"] = None
            __props__.__dict__["is_encrypted"] = None
            __props__.__dict__["used_storage_space"] = None
            __props__.__dict__["zone_description"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:rabbitmq/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            apply_private_dns_to_public: Optional[pulumi.Input[builtins.bool]] = None,
            arch_type: Optional[pulumi.Input[builtins.str]] = None,
            charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
            compute_spec: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceEndpointArgs', 'InstanceEndpointArgsDict']]]]] = None,
            instance_description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_status: Optional[pulumi.Input[builtins.str]] = None,
            is_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            storage_space: Optional[pulumi.Input[builtins.int]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            used_storage_space: Optional[pulumi.Input[builtins.int]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None,
            user_password: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_description: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 创建实例的主账号ID。
        :param pulumi.Input[builtins.bool] apply_private_dns_to_public: 是否已开启公网解析功能。true：已开启, false：已关闭
        :param pulumi.Input[builtins.str] arch_type: 实例的类型，即集群版或单机版。
        :param pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_id: RabbitMQ 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] instance_status: 实例状态。
        :param pulumi.Input[builtins.bool] is_encrypted: 是否开启了云盘加密。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.int] used_storage_space: 实例已用存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_description: 可用区的描述信息。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["apply_private_dns_to_public"] = apply_private_dns_to_public
        __props__.__dict__["arch_type"] = arch_type
        __props__.__dict__["charge_detail"] = charge_detail
        __props__.__dict__["compute_spec"] = compute_spec
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["instance_description"] = instance_description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_status"] = instance_status
        __props__.__dict__["is_encrypted"] = is_encrypted
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["storage_space"] = storage_space
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["used_storage_space"] = used_storage_space
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["user_password"] = user_password
        __props__.__dict__["version"] = version
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_description"] = zone_description
        __props__.__dict__["zone_id"] = zone_id
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        创建实例的主账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="applyPrivateDnsToPublic")
    def apply_private_dns_to_public(self) -> pulumi.Output[builtins.bool]:
        """
        是否已开启公网解析功能。true：已开启, false：已关闭
        """
        return pulumi.get(self, "apply_private_dns_to_public")

    @property
    @pulumi.getter(name="archType")
    def arch_type(self) -> pulumi.Output[builtins.str]:
        """
        实例的类型，即集群版或单机版。
        """
        return pulumi.get(self, "arch_type")

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> pulumi.Output['outputs.InstanceChargeDetail']:
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output[Sequence['outputs.InstanceEndpoint']]:
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> pulumi.Output[builtins.str]:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> pulumi.Output[builtins.str]:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启了云盘加密。
        """
        return pulumi.get(self, "is_encrypted")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> pulumi.Output[builtins.int]:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="usedStorageSpace")
    def used_storage_space(self) -> pulumi.Output[builtins.int]:
        """
        实例已用存储空间。单位为 GiB。
        """
        return pulumi.get(self, "used_storage_space")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneDescription")
    def zone_description(self) -> pulumi.Output[builtins.str]:
        """
        可用区的描述信息。
        """
        return pulumi.get(self, "zone_description")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")

