# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FlowLogArgs', 'FlowLog']

@pulumi.input_type
class FlowLogArgs:
    def __init__(__self__, *,
                 aggregation_interval: pulumi.Input[builtins.int],
                 flow_log_name: pulumi.Input[builtins.str],
                 log_project_name: pulumi.Input[builtins.str],
                 log_topic_name: pulumi.Input[builtins.str],
                 resource_id: pulumi.Input[builtins.str],
                 resource_type: pulumi.Input[builtins.str],
                 traffic_type: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]] = None):
        """
        The set of arguments for constructing a FlowLog resource.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        pulumi.set(__self__, "aggregation_interval", aggregation_interval)
        pulumi.set(__self__, "flow_log_name", flow_log_name)
        pulumi.set(__self__, "log_project_name", log_project_name)
        pulumi.set(__self__, "log_topic_name", log_topic_name)
        pulumi.set(__self__, "resource_id", resource_id)
        pulumi.set(__self__, "resource_type", resource_type)
        pulumi.set(__self__, "traffic_type", traffic_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> pulumi.Input[builtins.int]:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @aggregation_interval.setter
    def aggregation_interval(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "aggregation_interval", value)

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> pulumi.Input[builtins.str]:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @flow_log_name.setter
    def flow_log_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flow_log_name", value)

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> pulumi.Input[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @log_project_name.setter
    def log_project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_project_name", value)

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> pulumi.Input[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @log_topic_name.setter
    def log_topic_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_topic_name", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[builtins.str]:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Input[builtins.str]:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> pulumi.Input[builtins.str]:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @traffic_type.setter
    def traffic_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "traffic_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _FlowLogState:
    def __init__(__self__, *,
                 aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_index: Optional[pulumi.Input[builtins.bool]] = None,
                 flow_log_id: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_id: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_id: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]] = None,
                 traffic_type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FlowLog resources.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] business_status: 流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.str] created_at: 流日志的创建时间。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_index: 是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        :param pulumi.Input[builtins.str] flow_log_id: 流日志的ID。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] lock_reason: 流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        :param pulumi.Input[builtins.str] log_project_id: 流日志项目的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_id: 流日志主题的ID。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        :param pulumi.Input[builtins.str] updated_at: 更新流日志的时间。
        :param pulumi.Input[builtins.str] vpc_id: 流日志的VPC的ID。
        """
        if aggregation_interval is not None:
            pulumi.set(__self__, "aggregation_interval", aggregation_interval)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_index is not None:
            pulumi.set(__self__, "enable_index", enable_index)
        if flow_log_id is not None:
            pulumi.set(__self__, "flow_log_id", flow_log_id)
        if flow_log_name is not None:
            pulumi.set(__self__, "flow_log_name", flow_log_name)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if log_project_id is not None:
            pulumi.set(__self__, "log_project_id", log_project_id)
        if log_project_name is not None:
            pulumi.set(__self__, "log_project_name", log_project_name)
        if log_topic_id is not None:
            pulumi.set(__self__, "log_topic_id", log_topic_id)
        if log_topic_name is not None:
            pulumi.set(__self__, "log_topic_name", log_topic_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if traffic_type is not None:
            pulumi.set(__self__, "traffic_type", traffic_type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @aggregation_interval.setter
    def aggregation_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "aggregation_interval", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableIndex")
    def enable_index(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        """
        return pulumi.get(self, "enable_index")

    @enable_index.setter
    def enable_index(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_index", value)

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的ID。
        """
        return pulumi.get(self, "flow_log_id")

    @flow_log_id.setter
    def flow_log_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow_log_id", value)

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @flow_log_name.setter
    def flow_log_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow_log_name", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="logProjectId")
    def log_project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志项目的ID。
        """
        return pulumi.get(self, "log_project_id")

    @log_project_id.setter
    def log_project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_project_id", value)

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @log_project_name.setter
    def log_project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_project_name", value)

    @property
    @pulumi.getter(name="logTopicId")
    def log_topic_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志主题的ID。
        """
        return pulumi.get(self, "log_topic_id")

    @log_topic_id.setter
    def log_topic_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_topic_id", value)

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @log_topic_name.setter
    def log_topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_topic_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @traffic_type.setter
    def traffic_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_type", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新流日志的时间。
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:vpc/flowLog:FlowLog")
class FlowLog(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FlowLogTagArgs', 'FlowLogTagArgsDict']]]]] = None,
                 traffic_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        流日志对网卡出入流量的日志数据按需聚合处理后，投递至 日志服务 存储和检索分析，您可以根据流日志的分析监控网络流量、排查网络问题、优化网络架构。VPC流日志记录VPC网络流量的详细信息，用于网络监控、流量分析和故障排查。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_flow_log_demo = bytepluscc.vpc.FlowLog("VPCFlowLogDemo",
            aggregation_interval=10,
            description="this is a test flow log",
            flow_log_name="FlowLog-ccapi-test",
            log_project_name="ccapi-test-flow-log",
            log_topic_name="test-flow-log",
            project_name="default",
            resource_id="vpc-rrco37ovjq4gv0xxxxxx",
            resource_type="vpc",
            status="Active",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            traffic_type="All")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/flowLog:FlowLog example "flow_log_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlowLogArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        流日志对网卡出入流量的日志数据按需聚合处理后，投递至 日志服务 存储和检索分析，您可以根据流日志的分析监控网络流量、排查网络问题、优化网络架构。VPC流日志记录VPC网络流量的详细信息，用于网络监控、流量分析和故障排查。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_flow_log_demo = bytepluscc.vpc.FlowLog("VPCFlowLogDemo",
            aggregation_interval=10,
            description="this is a test flow log",
            flow_log_name="FlowLog-ccapi-test",
            log_project_name="ccapi-test-flow-log",
            log_topic_name="test-flow-log",
            project_name="default",
            resource_id="vpc-rrco37ovjq4gv0xxxxxx",
            resource_type="vpc",
            status="Active",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            traffic_type="All")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/flowLog:FlowLog example "flow_log_id"
        ```

        :param str resource_name: The name of the resource.
        :param FlowLogArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlowLogArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FlowLogTagArgs', 'FlowLogTagArgsDict']]]]] = None,
                 traffic_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlowLogArgs.__new__(FlowLogArgs)

            if aggregation_interval is None and not opts.urn:
                raise TypeError("Missing required property 'aggregation_interval'")
            __props__.__dict__["aggregation_interval"] = aggregation_interval
            __props__.__dict__["description"] = description
            if flow_log_name is None and not opts.urn:
                raise TypeError("Missing required property 'flow_log_name'")
            __props__.__dict__["flow_log_name"] = flow_log_name
            if log_project_name is None and not opts.urn:
                raise TypeError("Missing required property 'log_project_name'")
            __props__.__dict__["log_project_name"] = log_project_name
            if log_topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'log_topic_name'")
            __props__.__dict__["log_topic_name"] = log_topic_name
            __props__.__dict__["project_name"] = project_name
            if resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_id'")
            __props__.__dict__["resource_id"] = resource_id
            if resource_type is None and not opts.urn:
                raise TypeError("Missing required property 'resource_type'")
            __props__.__dict__["resource_type"] = resource_type
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
            if traffic_type is None and not opts.urn:
                raise TypeError("Missing required property 'traffic_type'")
            __props__.__dict__["traffic_type"] = traffic_type
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["enable_index"] = None
            __props__.__dict__["flow_log_id"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["log_project_id"] = None
            __props__.__dict__["log_topic_id"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["vpc_id"] = None
        super(FlowLog, __self__).__init__(
            'bytepluscc:vpc/flowLog:FlowLog',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_index: Optional[pulumi.Input[builtins.bool]] = None,
            flow_log_id: Optional[pulumi.Input[builtins.str]] = None,
            flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            log_project_id: Optional[pulumi.Input[builtins.str]] = None,
            log_project_name: Optional[pulumi.Input[builtins.str]] = None,
            log_topic_id: Optional[pulumi.Input[builtins.str]] = None,
            log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FlowLogTagArgs', 'FlowLogTagArgsDict']]]]] = None,
            traffic_type: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'FlowLog':
        """
        Get an existing FlowLog resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] business_status: 流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.str] created_at: 流日志的创建时间。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_index: 是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        :param pulumi.Input[builtins.str] flow_log_id: 流日志的ID。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] lock_reason: 流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        :param pulumi.Input[builtins.str] log_project_id: 流日志项目的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_id: 流日志主题的ID。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        :param pulumi.Input[builtins.str] updated_at: 更新流日志的时间。
        :param pulumi.Input[builtins.str] vpc_id: 流日志的VPC的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlowLogState.__new__(_FlowLogState)

        __props__.__dict__["aggregation_interval"] = aggregation_interval
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_index"] = enable_index
        __props__.__dict__["flow_log_id"] = flow_log_id
        __props__.__dict__["flow_log_name"] = flow_log_name
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["log_project_id"] = log_project_id
        __props__.__dict__["log_project_name"] = log_project_name
        __props__.__dict__["log_topic_id"] = log_topic_id
        __props__.__dict__["log_topic_name"] = log_topic_name
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["traffic_type"] = traffic_type
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["vpc_id"] = vpc_id
        return FlowLog(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> pulumi.Output[builtins.int]:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        流日志的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableIndex")
    def enable_index(self) -> pulumi.Output[builtins.bool]:
        """
        是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        """
        return pulumi.get(self, "enable_index")

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志的ID。
        """
        return pulumi.get(self, "flow_log_id")

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> pulumi.Output[builtins.str]:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="logProjectId")
    def log_project_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志项目的ID。
        """
        return pulumi.get(self, "log_project_id")

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> pulumi.Output[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @property
    @pulumi.getter(name="logTopicId")
    def log_topic_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志主题的ID。
        """
        return pulumi.get(self, "log_topic_id")

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> pulumi.Output[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[builtins.str]:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[builtins.str]:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.FlowLogTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> pulumi.Output[builtins.str]:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        更新流日志的时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

