# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccesskeyArgs', 'Accesskey']

@pulumi.input_type
class AccesskeyArgs:
    def __init__(__self__, *,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Accesskey resource.
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _AccesskeyState:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 last_login_date: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 request_time: Optional[pulumi.Input[builtins.str]] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 service: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Accesskey resources.
        :param pulumi.Input[builtins.str] access_key_id: 密钥ID（Access Key Id）。
        :param pulumi.Input[builtins.str] created_time: 密钥创建时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] last_login_date: 最后登录时间。
        :param pulumi.Input[builtins.str] region: API密钥最后访问的地域。
        :param pulumi.Input[builtins.str] request_time: API密钥的最后使用的时间。
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] service: API密钥最后访问的服务的英文简称。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] updated_time: 密钥更新时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if last_login_date is not None:
            pulumi.set(__self__, "last_login_date", last_login_date)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if request_time is not None:
            pulumi.set(__self__, "request_time", request_time)
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥ID（Access Key Id）。
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥创建时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        最后登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @last_login_date.setter
    def last_login_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_login_date", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API密钥最后访问的地域。
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API密钥的最后使用的时间。
        """
        return pulumi.get(self, "request_time")

    @request_time.setter
    def request_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "request_time", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API密钥最后访问的服务的英文简称。
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥更新时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.type_token("bytepluscc:iam/accesskey:Accesskey")
class Accesskey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        访问控制(Identity and Access Management，缩写为IAM)是火山引擎为客户提供的一套权限管理系统，用于控制不同身份对云资源的访问权限。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        accesskey_demo = bytepluscc.iam.Accesskey("AccesskeyDemo", user_name="s2222")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/accesskey:Accesskey example "access_key_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AccesskeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        访问控制(Identity and Access Management，缩写为IAM)是火山引擎为客户提供的一套权限管理系统，用于控制不同身份对云资源的访问权限。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        accesskey_demo = bytepluscc.iam.Accesskey("AccesskeyDemo", user_name="s2222")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/accesskey:Accesskey example "access_key_id"
        ```

        :param str resource_name: The name of the resource.
        :param AccesskeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccesskeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccesskeyArgs.__new__(AccesskeyArgs)

            __props__.__dict__["secret_access_key"] = secret_access_key
            __props__.__dict__["status"] = status
            __props__.__dict__["user_name"] = user_name
            __props__.__dict__["access_key_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["last_login_date"] = None
            __props__.__dict__["region"] = None
            __props__.__dict__["request_time"] = None
            __props__.__dict__["service"] = None
            __props__.__dict__["updated_time"] = None
        super(Accesskey, __self__).__init__(
            'bytepluscc:iam/accesskey:Accesskey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            last_login_date: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            request_time: Optional[pulumi.Input[builtins.str]] = None,
            secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
            service: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Accesskey':
        """
        Get an existing Accesskey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_key_id: 密钥ID（Access Key Id）。
        :param pulumi.Input[builtins.str] created_time: 密钥创建时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] last_login_date: 最后登录时间。
        :param pulumi.Input[builtins.str] region: API密钥最后访问的地域。
        :param pulumi.Input[builtins.str] request_time: API密钥的最后使用的时间。
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] service: API密钥最后访问的服务的英文简称。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] updated_time: 密钥更新时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccesskeyState.__new__(_AccesskeyState)

        __props__.__dict__["access_key_id"] = access_key_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["last_login_date"] = last_login_date
        __props__.__dict__["region"] = region
        __props__.__dict__["request_time"] = request_time
        __props__.__dict__["secret_access_key"] = secret_access_key
        __props__.__dict__["service"] = service
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["user_name"] = user_name
        return Accesskey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Output[builtins.str]:
        """
        密钥ID（Access Key Id）。
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        密钥创建时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> pulumi.Output[builtins.str]:
        """
        最后登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        API密钥最后访问的地域。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> pulumi.Output[builtins.str]:
        """
        API密钥的最后使用的时间。
        """
        return pulumi.get(self, "request_time")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> pulumi.Output[builtins.str]:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[builtins.str]:
        """
        API密钥最后访问的服务的英文简称。
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        密钥更新时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")

