# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AllowListAssociatedInstance',
    'AllowListSecurityGroupBindInfo',
    'GetAllowListAssociatedInstanceResult',
    'GetAllowListSecurityGroupBindInfoResult',
]

@pulumi.output_type
class AllowListAssociatedInstance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "instanceId":
            suggest = "instance_id"
        elif key == "instanceName":
            suggest = "instance_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AllowListAssociatedInstance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AllowListAssociatedInstance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AllowListAssociatedInstance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 instance_id: Optional[builtins.str] = None,
                 instance_name: Optional[builtins.str] = None,
                 vpc: Optional[builtins.str] = None):
        """
        :param builtins.str instance_id: 实例 ID。
        :param builtins.str instance_name: 实例名称。
        :param builtins.str vpc: 实例所属的 VPC ID。
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[builtins.str]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter
    def vpc(self) -> Optional[builtins.str]:
        """
        实例所属的 VPC ID。
        """
        return pulumi.get(self, "vpc")


@pulumi.output_type
class AllowListSecurityGroupBindInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bindMode":
            suggest = "bind_mode"
        elif key == "ipLists":
            suggest = "ip_lists"
        elif key == "securityGroupId":
            suggest = "security_group_id"
        elif key == "securityGroupName":
            suggest = "security_group_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AllowListSecurityGroupBindInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AllowListSecurityGroupBindInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AllowListSecurityGroupBindInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bind_mode: Optional[builtins.str] = None,
                 ip_lists: Optional[Sequence[builtins.str]] = None,
                 security_group_id: Optional[builtins.str] = None,
                 security_group_name: Optional[builtins.str] = None):
        """
        :param builtins.str bind_mode: 关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        :param Sequence[builtins.str] ip_lists: 安全组中的 IP 列表。
        :param builtins.str security_group_id: 安全组 ID。
        :param builtins.str security_group_name: 安全组名称。
        """
        if bind_mode is not None:
            pulumi.set(__self__, "bind_mode", bind_mode)
        if ip_lists is not None:
            pulumi.set(__self__, "ip_lists", ip_lists)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if security_group_name is not None:
            pulumi.set(__self__, "security_group_name", security_group_name)

    @property
    @pulumi.getter(name="bindMode")
    def bind_mode(self) -> Optional[builtins.str]:
        """
        关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        """
        return pulumi.get(self, "bind_mode")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Optional[Sequence[builtins.str]]:
        """
        安全组中的 IP 列表。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[builtins.str]:
        """
        安全组 ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> Optional[builtins.str]:
        """
        安全组名称。
        """
        return pulumi.get(self, "security_group_name")


@pulumi.output_type
class GetAllowListAssociatedInstanceResult(dict):
    def __init__(__self__, *,
                 instance_id: builtins.str,
                 instance_name: builtins.str,
                 vpc: builtins.str):
        """
        :param builtins.str instance_id: 实例 ID。
        :param builtins.str instance_name: 实例名称。
        :param builtins.str vpc: 实例所属的 VPC ID。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "vpc", vpc)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter
    def vpc(self) -> builtins.str:
        """
        实例所属的 VPC ID。
        """
        return pulumi.get(self, "vpc")


@pulumi.output_type
class GetAllowListSecurityGroupBindInfoResult(dict):
    def __init__(__self__, *,
                 bind_mode: builtins.str,
                 ip_lists: Sequence[builtins.str],
                 security_group_id: builtins.str,
                 security_group_name: builtins.str):
        """
        :param builtins.str bind_mode: 关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        :param Sequence[builtins.str] ip_lists: 安全组中的 IP 列表。
        :param builtins.str security_group_id: 安全组 ID。
        :param builtins.str security_group_name: 安全组名称。
        """
        pulumi.set(__self__, "bind_mode", bind_mode)
        pulumi.set(__self__, "ip_lists", ip_lists)
        pulumi.set(__self__, "security_group_id", security_group_id)
        pulumi.set(__self__, "security_group_name", security_group_name)

    @property
    @pulumi.getter(name="bindMode")
    def bind_mode(self) -> builtins.str:
        """
        关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        """
        return pulumi.get(self, "bind_mode")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Sequence[builtins.str]:
        """
        安全组中的 IP 列表。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        """
        安全组 ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> builtins.str:
        """
        安全组名称。
        """
        return pulumi.get(self, "security_group_name")


