# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeploymentSetArgs', 'DeploymentSet']

@pulumi.input_type
class DeploymentSetArgs:
    def __init__(__self__, *,
                 deployment_set_name: pulumi.Input[builtins.str],
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DeploymentSet resource.
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        pulumi.set(__self__, "deployment_set_name", deployment_set_name)
        if deployment_set_group_number is not None:
            pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if group_count is not None:
            pulumi.set(__self__, "group_count", group_count)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> pulumi.Input[builtins.str]:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @deployment_set_name.setter
    def deployment_set_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "deployment_set_name", value)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @deployment_set_group_number.setter
    def deployment_set_group_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "deployment_set_group_number", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "granularity", value)

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @group_count.setter
    def group_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_count", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "strategy", value)


@pulumi.input_type
class _DeploymentSetState:
    def __init__(__self__, *,
                 capacities: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentSetCapacityArgs']]]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_amount: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DeploymentSet resources.
        :param pulumi.Input[builtins.str] created_at: 部署集的创建时间。
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] deployment_set_id: 部署集ID。
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[builtins.int] instance_amount: 部署集内的ECS实例数量。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        if capacities is not None:
            pulumi.set(__self__, "capacities", capacities)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if deployment_set_group_number is not None:
            pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id is not None:
            pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if deployment_set_name is not None:
            pulumi.set(__self__, "deployment_set_name", deployment_set_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if group_count is not None:
            pulumi.set(__self__, "group_count", group_count)
        if instance_amount is not None:
            pulumi.set(__self__, "instance_amount", instance_amount)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter
    def capacities(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentSetCapacityArgs']]]]:
        return pulumi.get(self, "capacities")

    @capacities.setter
    def capacities(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentSetCapacityArgs']]]]):
        pulumi.set(self, "capacities", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @deployment_set_group_number.setter
    def deployment_set_group_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "deployment_set_group_number", value)

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @deployment_set_id.setter
    def deployment_set_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deployment_set_id", value)

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @deployment_set_name.setter
    def deployment_set_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deployment_set_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "granularity", value)

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @group_count.setter
    def group_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_count", value)

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集内的ECS实例数量。
        """
        return pulumi.get(self, "instance_amount")

    @instance_amount.setter
    def instance_amount(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "instance_amount", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "strategy", value)


@pulumi.type_token("bytepluscc:ecs/deploymentSet:DeploymentSet")
class DeploymentSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        部署集是在底层硬件维度上控制实例分散部署的策略，可以实现物理层级的安全隔离。您可以通过创建部署集，使实例分散部署在不同的底层硬件上，用于保障业务的底层容灾能力及高可用性。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        ecs_deployment_set_demo = bytepluscc.ecs.DeploymentSet("EcsDeploymentSetDemo",
            description="this is a test DeploymentSet",
            deployment_set_name="test-deployment-set",
            granularity="host",
            instance_ids=["i-yedvixxxxxva4izkjtl"],
            deployment_set_group_number=1,
            strategy="Availability")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/deploymentSet:DeploymentSet example "deployment_set_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        部署集是在底层硬件维度上控制实例分散部署的策略，可以实现物理层级的安全隔离。您可以通过创建部署集，使实例分散部署在不同的底层硬件上，用于保障业务的底层容灾能力及高可用性。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        ecs_deployment_set_demo = bytepluscc.ecs.DeploymentSet("EcsDeploymentSetDemo",
            description="this is a test DeploymentSet",
            deployment_set_name="test-deployment-set",
            granularity="host",
            instance_ids=["i-yedvixxxxxva4izkjtl"],
            deployment_set_group_number=1,
            strategy="Availability")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/deploymentSet:DeploymentSet example "deployment_set_id"
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentSetArgs.__new__(DeploymentSetArgs)

            __props__.__dict__["deployment_set_group_number"] = deployment_set_group_number
            if deployment_set_name is None and not opts.urn:
                raise TypeError("Missing required property 'deployment_set_name'")
            __props__.__dict__["deployment_set_name"] = deployment_set_name
            __props__.__dict__["description"] = description
            __props__.__dict__["granularity"] = granularity
            __props__.__dict__["group_count"] = group_count
            __props__.__dict__["instance_ids"] = instance_ids
            __props__.__dict__["strategy"] = strategy
            __props__.__dict__["capacities"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["deployment_set_id"] = None
            __props__.__dict__["instance_amount"] = None
        super(DeploymentSet, __self__).__init__(
            'bytepluscc:ecs/deploymentSet:DeploymentSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacities: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DeploymentSetCapacityArgs', 'DeploymentSetCapacityArgsDict']]]]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
            deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
            deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            granularity: Optional[pulumi.Input[builtins.str]] = None,
            group_count: Optional[pulumi.Input[builtins.int]] = None,
            instance_amount: Optional[pulumi.Input[builtins.int]] = None,
            instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            strategy: Optional[pulumi.Input[builtins.str]] = None) -> 'DeploymentSet':
        """
        Get an existing DeploymentSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: 部署集的创建时间。
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] deployment_set_id: 部署集ID。
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[builtins.int] instance_amount: 部署集内的ECS实例数量。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeploymentSetState.__new__(_DeploymentSetState)

        __props__.__dict__["capacities"] = capacities
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["deployment_set_group_number"] = deployment_set_group_number
        __props__.__dict__["deployment_set_id"] = deployment_set_id
        __props__.__dict__["deployment_set_name"] = deployment_set_name
        __props__.__dict__["description"] = description
        __props__.__dict__["granularity"] = granularity
        __props__.__dict__["group_count"] = group_count
        __props__.__dict__["instance_amount"] = instance_amount
        __props__.__dict__["instance_ids"] = instance_ids
        __props__.__dict__["strategy"] = strategy
        return DeploymentSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def capacities(self) -> pulumi.Output[Sequence['outputs.DeploymentSetCapacity']]:
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        部署集的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> pulumi.Output[builtins.int]:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> pulumi.Output[builtins.str]:
        """
        部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> pulumi.Output[builtins.str]:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def granularity(self) -> pulumi.Output[builtins.str]:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> pulumi.Output[builtins.int]:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> pulumi.Output[builtins.int]:
        """
        部署集内的ECS实例数量。
        """
        return pulumi.get(self, "instance_amount")

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Output[builtins.str]:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")

