# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTrafficMirrorFilterResult',
    'AwaitableGetTrafficMirrorFilterResult',
    'get_traffic_mirror_filter',
    'get_traffic_mirror_filter_output',
]

@pulumi.output_type
class GetTrafficMirrorFilterResult:
    """
    A collection of values returned by getTrafficMirrorFilter.
    """
    def __init__(__self__, created_time=None, description=None, egress_filter_rules=None, id=None, ingress_filter_rules=None, project_name=None, status=None, tags=None, traffic_mirror_filter_id=None, traffic_mirror_filter_name=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if egress_filter_rules and not isinstance(egress_filter_rules, list):
            raise TypeError("Expected argument 'egress_filter_rules' to be a list")
        pulumi.set(__self__, "egress_filter_rules", egress_filter_rules)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ingress_filter_rules and not isinstance(ingress_filter_rules, list):
            raise TypeError("Expected argument 'ingress_filter_rules' to be a list")
        pulumi.set(__self__, "ingress_filter_rules", ingress_filter_rules)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if traffic_mirror_filter_id and not isinstance(traffic_mirror_filter_id, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_filter_name and not isinstance(traffic_mirror_filter_name, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_name' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_name", traffic_mirror_filter_name)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        筛选条件的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        筛选条件实例描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="egressFilterRules")
    def egress_filter_rules(self) -> Sequence['outputs.GetTrafficMirrorFilterEgressFilterRuleResult']:
        """
        出方向筛选规则的详细信息。
        """
        return pulumi.get(self, "egress_filter_rules")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ingressFilterRules")
    def ingress_filter_rules(self) -> Sequence['outputs.GetTrafficMirrorFilterIngressFilterRuleResult']:
        """
        入方向筛选规则的详细信息。
        """
        return pulumi.get(self, "ingress_filter_rules")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        筛选条件所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        筛选条件状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTrafficMirrorFilterTagResult']:
        """
        标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> builtins.str:
        """
        筛选条件实例ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorFilterName")
    def traffic_mirror_filter_name(self) -> builtins.str:
        """
        筛选条件名称。
        """
        return pulumi.get(self, "traffic_mirror_filter_name")


class AwaitableGetTrafficMirrorFilterResult(GetTrafficMirrorFilterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorFilterResult(
            created_time=self.created_time,
            description=self.description,
            egress_filter_rules=self.egress_filter_rules,
            id=self.id,
            ingress_filter_rules=self.ingress_filter_rules,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            traffic_mirror_filter_id=self.traffic_mirror_filter_id,
            traffic_mirror_filter_name=self.traffic_mirror_filter_name)


def get_traffic_mirror_filter(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorFilterResult:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorFilter


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getTrafficMirrorFilter:getTrafficMirrorFilter', __args__, opts=opts, typ=GetTrafficMirrorFilterResult).value

    return AwaitableGetTrafficMirrorFilterResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        egress_filter_rules=pulumi.get(__ret__, 'egress_filter_rules'),
        id=pulumi.get(__ret__, 'id'),
        ingress_filter_rules=pulumi.get(__ret__, 'ingress_filter_rules'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        traffic_mirror_filter_id=pulumi.get(__ret__, 'traffic_mirror_filter_id'),
        traffic_mirror_filter_name=pulumi.get(__ret__, 'traffic_mirror_filter_name'))
def get_traffic_mirror_filter_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrafficMirrorFilterResult]:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorFilter


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getTrafficMirrorFilter:getTrafficMirrorFilter', __args__, opts=opts, typ=GetTrafficMirrorFilterResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorFilterResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        egress_filter_rules=pulumi.get(__response__, 'egress_filter_rules'),
        id=pulumi.get(__response__, 'id'),
        ingress_filter_rules=pulumi.get(__response__, 'ingress_filter_rules'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        traffic_mirror_filter_id=pulumi.get(__response__, 'traffic_mirror_filter_id'),
        traffic_mirror_filter_name=pulumi.get(__response__, 'traffic_mirror_filter_name')))
