# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HaVipArgs', 'HaVip']

@pulumi.input_type
class HaVipArgs:
    def __init__(__self__, *,
                 subnet_id: pulumi.Input[builtins.str],
                 associated_eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 associated_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ha_vip_name: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['HaVipTagArgs']]]] = None):
        """
        The set of arguments for constructing a HaVip resource.
        :param pulumi.Input[builtins.str] subnet_id: HAVIP所属的子网 ID。
        :param pulumi.Input[builtins.str] associated_eip_id: HAVIP绑定的公网IP的ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] associated_instance_ids: 绑定HAVIP的实例ID列表。
        :param pulumi.Input[builtins.str] associated_instance_type: 绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        :param pulumi.Input[builtins.str] description: HAVIP的描述。长度限制为0～255个字符。
        :param pulumi.Input[builtins.str] ha_vip_name: HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        :param pulumi.Input[builtins.str] ip_address: HAVIP的IP地址。
        """
        pulumi.set(__self__, "subnet_id", subnet_id)
        if associated_eip_id is not None:
            pulumi.set(__self__, "associated_eip_id", associated_eip_id)
        if associated_instance_ids is not None:
            pulumi.set(__self__, "associated_instance_ids", associated_instance_ids)
        if associated_instance_type is not None:
            pulumi.set(__self__, "associated_instance_type", associated_instance_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ha_vip_name is not None:
            pulumi.set(__self__, "ha_vip_name", ha_vip_name)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        HAVIP所属的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="associatedEipId")
    def associated_eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP绑定的公网IP的ID。
        """
        return pulumi.get(self, "associated_eip_id")

    @associated_eip_id.setter
    def associated_eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_eip_id", value)

    @property
    @pulumi.getter(name="associatedInstanceIds")
    def associated_instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        绑定HAVIP的实例ID列表。
        """
        return pulumi.get(self, "associated_instance_ids")

    @associated_instance_ids.setter
    def associated_instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "associated_instance_ids", value)

    @property
    @pulumi.getter(name="associatedInstanceType")
    def associated_instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        """
        return pulumi.get(self, "associated_instance_type")

    @associated_instance_type.setter
    def associated_instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_instance_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的描述。长度限制为0～255个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="haVipName")
    def ha_vip_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        """
        return pulumi.get(self, "ha_vip_name")

    @ha_vip_name.setter
    def ha_vip_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ha_vip_name", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HaVipTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HaVipTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _HaVipState:
    def __init__(__self__, *,
                 associated_eip_address: Optional[pulumi.Input[builtins.str]] = None,
                 associated_eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 associated_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ha_vip_id: Optional[pulumi.Input[builtins.str]] = None,
                 ha_vip_name: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 master_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['HaVipTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering HaVip resources.
        :param pulumi.Input[builtins.str] associated_eip_address: HAVIP绑定的公网IP的IP地址。
        :param pulumi.Input[builtins.str] associated_eip_id: HAVIP绑定的公网IP的ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] associated_instance_ids: 绑定HAVIP的实例ID列表。
        :param pulumi.Input[builtins.str] associated_instance_type: 绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        :param pulumi.Input[builtins.str] created_at: HAVIP的创建时间。
        :param pulumi.Input[builtins.str] description: HAVIP的描述。长度限制为0～255个字符。
        :param pulumi.Input[builtins.str] ha_vip_id: HAVIP的ID。
        :param pulumi.Input[builtins.str] ha_vip_name: HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        :param pulumi.Input[builtins.str] ip_address: HAVIP的IP地址。
        :param pulumi.Input[builtins.str] master_instance_id: 与HAVIP绑定的主实例的ID。
        :param pulumi.Input[builtins.str] project_name: HAVIP的项目名称。
        :param pulumi.Input[builtins.str] status: HAVIP的状态。Available：可用。Creating：创建中。InUse：使用中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: HAVIP所属的子网 ID。
        :param pulumi.Input[builtins.str] updated_at: HAVIP最近一次的修改时间。
        :param pulumi.Input[builtins.str] vpc_id: HAVIP所属的VPC ID。
        """
        if associated_eip_address is not None:
            pulumi.set(__self__, "associated_eip_address", associated_eip_address)
        if associated_eip_id is not None:
            pulumi.set(__self__, "associated_eip_id", associated_eip_id)
        if associated_instance_ids is not None:
            pulumi.set(__self__, "associated_instance_ids", associated_instance_ids)
        if associated_instance_type is not None:
            pulumi.set(__self__, "associated_instance_type", associated_instance_type)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ha_vip_id is not None:
            pulumi.set(__self__, "ha_vip_id", ha_vip_id)
        if ha_vip_name is not None:
            pulumi.set(__self__, "ha_vip_name", ha_vip_name)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if master_instance_id is not None:
            pulumi.set(__self__, "master_instance_id", master_instance_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="associatedEipAddress")
    def associated_eip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP绑定的公网IP的IP地址。
        """
        return pulumi.get(self, "associated_eip_address")

    @associated_eip_address.setter
    def associated_eip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_eip_address", value)

    @property
    @pulumi.getter(name="associatedEipId")
    def associated_eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP绑定的公网IP的ID。
        """
        return pulumi.get(self, "associated_eip_id")

    @associated_eip_id.setter
    def associated_eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_eip_id", value)

    @property
    @pulumi.getter(name="associatedInstanceIds")
    def associated_instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        绑定HAVIP的实例ID列表。
        """
        return pulumi.get(self, "associated_instance_ids")

    @associated_instance_ids.setter
    def associated_instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "associated_instance_ids", value)

    @property
    @pulumi.getter(name="associatedInstanceType")
    def associated_instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        """
        return pulumi.get(self, "associated_instance_type")

    @associated_instance_type.setter
    def associated_instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_instance_type", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的描述。长度限制为0～255个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="haVipId")
    def ha_vip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的ID。
        """
        return pulumi.get(self, "ha_vip_id")

    @ha_vip_id.setter
    def ha_vip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ha_vip_id", value)

    @property
    @pulumi.getter(name="haVipName")
    def ha_vip_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        """
        return pulumi.get(self, "ha_vip_name")

    @ha_vip_name.setter
    def ha_vip_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ha_vip_name", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        与HAVIP绑定的主实例的ID。
        """
        return pulumi.get(self, "master_instance_id")

    @master_instance_id.setter
    def master_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "master_instance_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP的状态。Available：可用。Creating：创建中。InUse：使用中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP所属的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HaVipTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HaVipTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP最近一次的修改时间。
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HAVIP所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:vpc/haVip:HaVip")
class HaVip(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 associated_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ha_vip_name: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HaVipTagArgs', 'HaVipTagArgsDict']]]]] = None,
                 __props__=None):
        """
        高可用虚拟IP是一种可独立持有，可根据实际业务需要随时创建或删除的私网IP资源。在主备集群场景下，高可用虚拟IP通常与高可用软件（如Keepalived、Window Server Failover Cluster）搭配使用，搭建高可用主备服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pchavip_demo = bytepluscc.vpc.HaVip("VPCHAVIPDemo",
            associated_eip_id="eip-1a1tzpbhmsphc8nvexxxxx",
            associated_instance_ids=[
                "eni-btw4pmtcabr45h0b2xxxxx",
                "eni-iiotcbjp7r4074o8xxxxx",
                "eni-3nrjyim6prm68931ebbxxxxx",
            ],
            associated_instance_type="NetworkInterface",
            description="this is a test",
            ha_vip_name="HaVip-test",
            ip_address="192.***.0.9",
            subnet_id="subnet-rrwqhg3qzxfkv0x57xxxxx",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/haVip:HaVip example "ha_vip_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associated_eip_id: HAVIP绑定的公网IP的ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] associated_instance_ids: 绑定HAVIP的实例ID列表。
        :param pulumi.Input[builtins.str] associated_instance_type: 绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        :param pulumi.Input[builtins.str] description: HAVIP的描述。长度限制为0～255个字符。
        :param pulumi.Input[builtins.str] ha_vip_name: HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        :param pulumi.Input[builtins.str] ip_address: HAVIP的IP地址。
        :param pulumi.Input[builtins.str] subnet_id: HAVIP所属的子网 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HaVipArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        高可用虚拟IP是一种可独立持有，可根据实际业务需要随时创建或删除的私网IP资源。在主备集群场景下，高可用虚拟IP通常与高可用软件（如Keepalived、Window Server Failover Cluster）搭配使用，搭建高可用主备服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pchavip_demo = bytepluscc.vpc.HaVip("VPCHAVIPDemo",
            associated_eip_id="eip-1a1tzpbhmsphc8nvexxxxx",
            associated_instance_ids=[
                "eni-btw4pmtcabr45h0b2xxxxx",
                "eni-iiotcbjp7r4074o8xxxxx",
                "eni-3nrjyim6prm68931ebbxxxxx",
            ],
            associated_instance_type="NetworkInterface",
            description="this is a test",
            ha_vip_name="HaVip-test",
            ip_address="192.***.0.9",
            subnet_id="subnet-rrwqhg3qzxfkv0x57xxxxx",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/haVip:HaVip example "ha_vip_id"
        ```

        :param str resource_name: The name of the resource.
        :param HaVipArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HaVipArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 associated_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ha_vip_name: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HaVipTagArgs', 'HaVipTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HaVipArgs.__new__(HaVipArgs)

            __props__.__dict__["associated_eip_id"] = associated_eip_id
            __props__.__dict__["associated_instance_ids"] = associated_instance_ids
            __props__.__dict__["associated_instance_type"] = associated_instance_type
            __props__.__dict__["description"] = description
            __props__.__dict__["ha_vip_name"] = ha_vip_name
            __props__.__dict__["ip_address"] = ip_address
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["associated_eip_address"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["ha_vip_id"] = None
            __props__.__dict__["master_instance_id"] = None
            __props__.__dict__["project_name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["vpc_id"] = None
        super(HaVip, __self__).__init__(
            'bytepluscc:vpc/haVip:HaVip',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            associated_eip_address: Optional[pulumi.Input[builtins.str]] = None,
            associated_eip_id: Optional[pulumi.Input[builtins.str]] = None,
            associated_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            associated_instance_type: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ha_vip_id: Optional[pulumi.Input[builtins.str]] = None,
            ha_vip_name: Optional[pulumi.Input[builtins.str]] = None,
            ip_address: Optional[pulumi.Input[builtins.str]] = None,
            master_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HaVipTagArgs', 'HaVipTagArgsDict']]]]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'HaVip':
        """
        Get an existing HaVip resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associated_eip_address: HAVIP绑定的公网IP的IP地址。
        :param pulumi.Input[builtins.str] associated_eip_id: HAVIP绑定的公网IP的ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] associated_instance_ids: 绑定HAVIP的实例ID列表。
        :param pulumi.Input[builtins.str] associated_instance_type: 绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        :param pulumi.Input[builtins.str] created_at: HAVIP的创建时间。
        :param pulumi.Input[builtins.str] description: HAVIP的描述。长度限制为0～255个字符。
        :param pulumi.Input[builtins.str] ha_vip_id: HAVIP的ID。
        :param pulumi.Input[builtins.str] ha_vip_name: HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        :param pulumi.Input[builtins.str] ip_address: HAVIP的IP地址。
        :param pulumi.Input[builtins.str] master_instance_id: 与HAVIP绑定的主实例的ID。
        :param pulumi.Input[builtins.str] project_name: HAVIP的项目名称。
        :param pulumi.Input[builtins.str] status: HAVIP的状态。Available：可用。Creating：创建中。InUse：使用中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: HAVIP所属的子网 ID。
        :param pulumi.Input[builtins.str] updated_at: HAVIP最近一次的修改时间。
        :param pulumi.Input[builtins.str] vpc_id: HAVIP所属的VPC ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HaVipState.__new__(_HaVipState)

        __props__.__dict__["associated_eip_address"] = associated_eip_address
        __props__.__dict__["associated_eip_id"] = associated_eip_id
        __props__.__dict__["associated_instance_ids"] = associated_instance_ids
        __props__.__dict__["associated_instance_type"] = associated_instance_type
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["ha_vip_id"] = ha_vip_id
        __props__.__dict__["ha_vip_name"] = ha_vip_name
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["master_instance_id"] = master_instance_id
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["vpc_id"] = vpc_id
        return HaVip(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associatedEipAddress")
    def associated_eip_address(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP绑定的公网IP的IP地址。
        """
        return pulumi.get(self, "associated_eip_address")

    @property
    @pulumi.getter(name="associatedEipId")
    def associated_eip_id(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP绑定的公网IP的ID。
        """
        return pulumi.get(self, "associated_eip_id")

    @property
    @pulumi.getter(name="associatedInstanceIds")
    def associated_instance_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        绑定HAVIP的实例ID列表。
        """
        return pulumi.get(self, "associated_instance_ids")

    @property
    @pulumi.getter(name="associatedInstanceType")
    def associated_instance_type(self) -> pulumi.Output[builtins.str]:
        """
        绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        """
        return pulumi.get(self, "associated_instance_type")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的描述。长度限制为0～255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="haVipId")
    def ha_vip_id(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的ID。
        """
        return pulumi.get(self, "ha_vip_id")

    @property
    @pulumi.getter(name="haVipName")
    def ha_vip_name(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        """
        return pulumi.get(self, "ha_vip_name")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        与HAVIP绑定的主实例的ID。
        """
        return pulumi.get(self, "master_instance_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP的状态。Available：可用。Creating：创建中。InUse：使用中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP所属的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.HaVipTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP最近一次的修改时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        HAVIP所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

