# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPermissionSetResult',
    'AwaitableGetPermissionSetResult',
    'get_permission_set',
    'get_permission_set_output',
]

@pulumi.output_type
class GetPermissionSetResult:
    """
    A collection of values returned by getPermissionSet.
    """
    def __init__(__self__, created_time=None, description=None, id=None, name=None, permission_policies=None, permission_set_id=None, relay_state=None, session_duration=None, status_notifications=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if permission_policies and not isinstance(permission_policies, list):
            raise TypeError("Expected argument 'permission_policies' to be a list")
        pulumi.set(__self__, "permission_policies", permission_policies)
        if permission_set_id and not isinstance(permission_set_id, str):
            raise TypeError("Expected argument 'permission_set_id' to be a str")
        pulumi.set(__self__, "permission_set_id", permission_set_id)
        if relay_state and not isinstance(relay_state, str):
            raise TypeError("Expected argument 'relay_state' to be a str")
        pulumi.set(__self__, "relay_state", relay_state)
        if session_duration and not isinstance(session_duration, int):
            raise TypeError("Expected argument 'session_duration' to be a int")
        pulumi.set(__self__, "session_duration", session_duration)
        if status_notifications and not isinstance(status_notifications, list):
            raise TypeError("Expected argument 'status_notifications' to be a list")
        pulumi.set(__self__, "status_notifications", status_notifications)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        权限集描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        权限集名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="permissionPolicies")
    def permission_policies(self) -> Sequence['outputs.GetPermissionSetPermissionPolicyResult']:
        """
        权限集下的策略列表。
        """
        return pulumi.get(self, "permission_policies")

    @property
    @pulumi.getter(name="permissionSetId")
    def permission_set_id(self) -> builtins.str:
        """
        权限集 ID。
        """
        return pulumi.get(self, "permission_set_id")

    @property
    @pulumi.getter(name="relayState")
    def relay_state(self) -> builtins.str:
        """
        跳转控制台 URL。
        """
        return pulumi.get(self, "relay_state")

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> builtins.int:
        """
        session 过期时间，单位秒。
        """
        return pulumi.get(self, "session_duration")

    @property
    @pulumi.getter(name="statusNotifications")
    def status_notifications(self) -> Sequence[builtins.str]:
        """
        状态通知配置。
        """
        return pulumi.get(self, "status_notifications")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetPermissionSetResult(GetPermissionSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPermissionSetResult(
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            name=self.name,
            permission_policies=self.permission_policies,
            permission_set_id=self.permission_set_id,
            relay_state=self.relay_state,
            session_duration=self.session_duration,
            status_notifications=self.status_notifications,
            updated_time=self.updated_time)


def get_permission_set(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPermissionSetResult:
    """
    Data Source schema for Byteplus::CloudIdentity::PermissionSet


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cloudidentity/getPermissionSet:getPermissionSet', __args__, opts=opts, typ=GetPermissionSetResult).value

    return AwaitableGetPermissionSetResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        permission_policies=pulumi.get(__ret__, 'permission_policies'),
        permission_set_id=pulumi.get(__ret__, 'permission_set_id'),
        relay_state=pulumi.get(__ret__, 'relay_state'),
        session_duration=pulumi.get(__ret__, 'session_duration'),
        status_notifications=pulumi.get(__ret__, 'status_notifications'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_permission_set_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPermissionSetResult]:
    """
    Data Source schema for Byteplus::CloudIdentity::PermissionSet


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cloudidentity/getPermissionSet:getPermissionSet', __args__, opts=opts, typ=GetPermissionSetResult)
    return __ret__.apply(lambda __response__: GetPermissionSetResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        permission_policies=pulumi.get(__response__, 'permission_policies'),
        permission_set_id=pulumi.get(__response__, 'permission_set_id'),
        relay_state=pulumi.get(__response__, 'relay_state'),
        session_duration=pulumi.get(__response__, 'session_duration'),
        status_notifications=pulumi.get(__response__, 'status_notifications'),
        updated_time=pulumi.get(__response__, 'updated_time')))
