# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AllowListAssociatedInstanceArgs',
    'AllowListAssociatedInstanceArgsDict',
    'AllowListSecurityGroupBindInfoArgs',
    'AllowListSecurityGroupBindInfoArgsDict',
]

MYPY = False

if not MYPY:
    class AllowListAssociatedInstanceArgsDict(TypedDict):
        instance_id: NotRequired[pulumi.Input[builtins.str]]
        """
        实例 ID。
        """
        instance_name: NotRequired[pulumi.Input[builtins.str]]
        """
        实例名称。
        """
        vpc: NotRequired[pulumi.Input[builtins.str]]
        """
        实例所属的 VPC ID。
        """
elif False:
    AllowListAssociatedInstanceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AllowListAssociatedInstanceArgs:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 vpc: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] vpc: 实例所属的 VPC ID。
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的 VPC ID。
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc", value)


if not MYPY:
    class AllowListSecurityGroupBindInfoArgsDict(TypedDict):
        bind_mode: NotRequired[pulumi.Input[builtins.str]]
        """
        关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        """
        ip_lists: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        安全组中的 IP 列表。
        """
        security_group_id: NotRequired[pulumi.Input[builtins.str]]
        """
        安全组 ID。
        """
        security_group_name: NotRequired[pulumi.Input[builtins.str]]
        """
        安全组名称。
        """
elif False:
    AllowListSecurityGroupBindInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AllowListSecurityGroupBindInfoArgs:
    def __init__(__self__, *,
                 bind_mode: Optional[pulumi.Input[builtins.str]] = None,
                 ip_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 security_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] bind_mode: 关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_lists: 安全组中的 IP 列表。
        :param pulumi.Input[builtins.str] security_group_id: 安全组 ID。
        :param pulumi.Input[builtins.str] security_group_name: 安全组名称。
        """
        if bind_mode is not None:
            pulumi.set(__self__, "bind_mode", bind_mode)
        if ip_lists is not None:
            pulumi.set(__self__, "ip_lists", ip_lists)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if security_group_name is not None:
            pulumi.set(__self__, "security_group_name", security_group_name)

    @property
    @pulumi.getter(name="bindMode")
    def bind_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        """
        return pulumi.get(self, "bind_mode")

    @bind_mode.setter
    def bind_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bind_mode", value)

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        安全组中的 IP 列表。
        """
        return pulumi.get(self, "ip_lists")

    @ip_lists.setter
    def ip_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_lists", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组 ID。
        """
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_group_id", value)

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组名称。
        """
        return pulumi.get(self, "security_group_name")

    @security_group_name.setter
    def security_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_group_name", value)


