# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccountSecureContactInfo',
    'AccountTag',
    'GetAccountSecureContactInfoResult',
    'GetAccountTagResult',
]

@pulumi.output_type
class AccountSecureContactInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "emailVerified":
            suggest = "email_verified"
        elif key == "newEmail":
            suggest = "new_email"
        elif key == "newPhone":
            suggest = "new_phone"
        elif key == "phoneVerified":
            suggest = "phone_verified"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AccountSecureContactInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AccountSecureContactInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AccountSecureContactInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 email: Optional[builtins.str] = None,
                 email_verified: Optional[builtins.int] = None,
                 new_email: Optional[builtins.str] = None,
                 new_phone: Optional[builtins.str] = None,
                 phone: Optional[builtins.str] = None,
                 phone_verified: Optional[builtins.int] = None):
        """
        :param builtins.str email: 安全邮箱。
        :param builtins.int email_verified: 安全邮箱是否验证，1: 未验证，2: 已验证。
        :param builtins.str new_email: 变更中的新邮箱。
        :param builtins.str new_phone: 变更中的新手机号。
        :param builtins.str phone: 安全手机号。
        :param builtins.int phone_verified: 安全手机号是否验证，1: 未验证，2: 已验证。
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if email_verified is not None:
            pulumi.set(__self__, "email_verified", email_verified)
        if new_email is not None:
            pulumi.set(__self__, "new_email", new_email)
        if new_phone is not None:
            pulumi.set(__self__, "new_phone", new_phone)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if phone_verified is not None:
            pulumi.set(__self__, "phone_verified", phone_verified)

    @property
    @pulumi.getter
    def email(self) -> Optional[builtins.str]:
        """
        安全邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> Optional[builtins.int]:
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "email_verified")

    @property
    @pulumi.getter(name="newEmail")
    def new_email(self) -> Optional[builtins.str]:
        """
        变更中的新邮箱。
        """
        return pulumi.get(self, "new_email")

    @property
    @pulumi.getter(name="newPhone")
    def new_phone(self) -> Optional[builtins.str]:
        """
        变更中的新手机号。
        """
        return pulumi.get(self, "new_phone")

    @property
    @pulumi.getter
    def phone(self) -> Optional[builtins.str]:
        """
        安全手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="phoneVerified")
    def phone_verified(self) -> Optional[builtins.int]:
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "phone_verified")


@pulumi.output_type
class AccountTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAccountSecureContactInfoResult(dict):
    def __init__(__self__, *,
                 email: builtins.str,
                 email_verified: builtins.int,
                 new_email: builtins.str,
                 new_phone: builtins.str,
                 phone: builtins.str,
                 phone_verified: builtins.int):
        """
        :param builtins.str email: 安全邮箱。
        :param builtins.int email_verified: 安全邮箱是否验证，1: 未验证，2: 已验证。
        :param builtins.str new_email: 变更中的新邮箱。
        :param builtins.str new_phone: 变更中的新手机号。
        :param builtins.str phone: 安全手机号。
        :param builtins.int phone_verified: 安全手机号是否验证，1: 未验证，2: 已验证。
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "email_verified", email_verified)
        pulumi.set(__self__, "new_email", new_email)
        pulumi.set(__self__, "new_phone", new_phone)
        pulumi.set(__self__, "phone", phone)
        pulumi.set(__self__, "phone_verified", phone_verified)

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        安全邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> builtins.int:
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "email_verified")

    @property
    @pulumi.getter(name="newEmail")
    def new_email(self) -> builtins.str:
        """
        变更中的新邮箱。
        """
        return pulumi.get(self, "new_email")

    @property
    @pulumi.getter(name="newPhone")
    def new_phone(self) -> builtins.str:
        """
        变更中的新手机号。
        """
        return pulumi.get(self, "new_phone")

    @property
    @pulumi.getter
    def phone(self) -> builtins.str:
        """
        安全手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="phoneVerified")
    def phone_verified(self) -> builtins.int:
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "phone_verified")


@pulumi.output_type
class GetAccountTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


