# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTrafficMirrorTargetResult',
    'AwaitableGetTrafficMirrorTargetResult',
    'get_traffic_mirror_target',
    'get_traffic_mirror_target_output',
]

@pulumi.output_type
class GetTrafficMirrorTargetResult:
    """
    A collection of values returned by getTrafficMirrorTarget.
    """
    def __init__(__self__, created_at=None, description=None, id=None, instance_id=None, instance_type=None, project_name=None, status=None, tags=None, traffic_mirror_target_id=None, traffic_mirror_target_name=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if traffic_mirror_target_id and not isinstance(traffic_mirror_target_id, str):
            raise TypeError("Expected argument 'traffic_mirror_target_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)
        if traffic_mirror_target_name and not isinstance(traffic_mirror_target_name, str):
            raise TypeError("Expected argument 'traffic_mirror_target_name' to be a str")
        pulumi.set(__self__, "traffic_mirror_target_name", traffic_mirror_target_name)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        镜像会话的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        镜像目的的资源ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        镜像目的所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        镜像目的状态。Available：可用。Creating：创建中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTrafficMirrorTargetTagResult']:
        """
        镜像目的的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> builtins.str:
        """
        镜像目的的ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @property
    @pulumi.getter(name="trafficMirrorTargetName")
    def traffic_mirror_target_name(self) -> builtins.str:
        """
        监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        return pulumi.get(self, "traffic_mirror_target_name")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        镜像会话的更新时间。
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetTrafficMirrorTargetResult(GetTrafficMirrorTargetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorTargetResult(
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            instance_id=self.instance_id,
            instance_type=self.instance_type,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            traffic_mirror_target_id=self.traffic_mirror_target_id,
            traffic_mirror_target_name=self.traffic_mirror_target_name,
            updated_at=self.updated_at)


def get_traffic_mirror_target(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorTargetResult:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorTarget


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getTrafficMirrorTarget:getTrafficMirrorTarget', __args__, opts=opts, typ=GetTrafficMirrorTargetResult).value

    return AwaitableGetTrafficMirrorTargetResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        traffic_mirror_target_id=pulumi.get(__ret__, 'traffic_mirror_target_id'),
        traffic_mirror_target_name=pulumi.get(__ret__, 'traffic_mirror_target_name'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_traffic_mirror_target_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrafficMirrorTargetResult]:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorTarget


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getTrafficMirrorTarget:getTrafficMirrorTarget', __args__, opts=opts, typ=GetTrafficMirrorTargetResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorTargetResult(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        traffic_mirror_target_id=pulumi.get(__response__, 'traffic_mirror_target_id'),
        traffic_mirror_target_name=pulumi.get(__response__, 'traffic_mirror_target_name'),
        updated_at=pulumi.get(__response__, 'updated_at')))
