# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AllowListArgs', 'AllowList']

@pulumi.input_type
class AllowListArgs:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a AllowList resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if ignore_instance_status is not None:
            pulumi.set(__self__, "ignore_instance_status", ignore_instance_status)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_lists is not None:
            pulumi.set(__self__, "user_allow_lists", user_allow_lists)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @ignore_instance_status.setter
    def ignore_instance_status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_instance_status", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")

    @user_allow_lists.setter
    def user_allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_allow_lists", value)


@pulumi.input_type
class _AllowListState:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AllowList resources.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID 。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单内的 IP 地址（或地址段）总数。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_lists: 白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_id is not None:
            pulumi.set(__self__, "allow_list_id", allow_list_id)
        if allow_list_ip_num is not None:
            pulumi.set(__self__, "allow_list_ip_num", allow_list_ip_num)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if associated_instances is not None:
            pulumi.set(__self__, "associated_instances", associated_instances)
        if ignore_instance_status is not None:
            pulumi.set(__self__, "ignore_instance_status", ignore_instance_status)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ip_lists is not None:
            pulumi.set(__self__, "ip_lists", ip_lists)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_lists is not None:
            pulumi.set(__self__, "user_allow_lists", user_allow_lists)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单 ID 。
        """
        return pulumi.get(self, "allow_list_id")

    @allow_list_id.setter
    def allow_list_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_id", value)

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单内的 IP 地址（或地址段）总数。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @allow_list_ip_num.setter
    def allow_list_ip_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_list_ip_num", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]:
        return pulumi.get(self, "associated_instances")

    @associated_instances.setter
    def associated_instances(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]):
        pulumi.set(self, "associated_instances", value)

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @ignore_instance_status.setter
    def ignore_instance_status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_instance_status", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        """
        return pulumi.get(self, "ip_lists")

    @ip_lists.setter
    def ip_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_lists", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")

    @user_allow_lists.setter
    def user_allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_allow_lists", value)


@pulumi.type_token("bytepluscc:rdsmysql/allowList:AllowList")
class AllowList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AllowListArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param AllowListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AllowListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AllowListArgs.__new__(AllowListArgs)

            __props__.__dict__["allow_list_category"] = allow_list_category
            __props__.__dict__["allow_list_desc"] = allow_list_desc
            __props__.__dict__["allow_list_name"] = allow_list_name
            __props__.__dict__["allow_list_type"] = allow_list_type
            __props__.__dict__["allow_lists"] = allow_lists
            __props__.__dict__["associated_instance_num"] = associated_instance_num
            __props__.__dict__["ignore_instance_status"] = ignore_instance_status
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["modify_mode"] = modify_mode
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["update_security_group"] = update_security_group
            __props__.__dict__["user_allow_lists"] = user_allow_lists
            __props__.__dict__["allow_list_id"] = None
            __props__.__dict__["allow_list_ip_num"] = None
            __props__.__dict__["associated_instances"] = None
            __props__.__dict__["ip_lists"] = None
        super(AllowList, __self__).__init__(
            'bytepluscc:rdsmysql/allowList:AllowList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
            allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
            allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
            associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListAssociatedInstanceArgs', 'AllowListAssociatedInstanceArgsDict']]]]] = None,
            ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            ip_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            modify_mode: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
            user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'AllowList':
        """
        Get an existing AllowList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID 。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单内的 IP 地址（或地址段）总数。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_lists: 白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AllowListState.__new__(_AllowListState)

        __props__.__dict__["allow_list_category"] = allow_list_category
        __props__.__dict__["allow_list_desc"] = allow_list_desc
        __props__.__dict__["allow_list_id"] = allow_list_id
        __props__.__dict__["allow_list_ip_num"] = allow_list_ip_num
        __props__.__dict__["allow_list_name"] = allow_list_name
        __props__.__dict__["allow_list_type"] = allow_list_type
        __props__.__dict__["allow_lists"] = allow_lists
        __props__.__dict__["associated_instance_num"] = associated_instance_num
        __props__.__dict__["associated_instances"] = associated_instances
        __props__.__dict__["ignore_instance_status"] = ignore_instance_status
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ip_lists"] = ip_lists
        __props__.__dict__["modify_mode"] = modify_mode
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["update_security_group"] = update_security_group
        __props__.__dict__["user_allow_lists"] = user_allow_lists
        return AllowList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> pulumi.Output[builtins.str]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> pulumi.Output[builtins.str]:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> pulumi.Output[builtins.str]:
        """
        白名单 ID 。
        """
        return pulumi.get(self, "allow_list_id")

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> pulumi.Output[builtins.int]:
        """
        白名单内的 IP 地址（或地址段）总数。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> pulumi.Output[builtins.str]:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> pulumi.Output[builtins.str]:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> pulumi.Output[builtins.int]:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> pulumi.Output[Sequence['outputs.AllowListAssociatedInstance']]:
        return pulumi.get(self, "associated_instances")

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> pulumi.Output[builtins.bool]:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> pulumi.Output[builtins.str]:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> pulumi.Output[Sequence['outputs.AllowListSecurityGroupBindInfo']]:
        return pulumi.get(self, "security_group_bind_infos")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> pulumi.Output[builtins.bool]:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")

