# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GroupMember',
    'PermissionSetPermissionPolicy',
    'GetGroupMemberResult',
    'GetPermissionSetPermissionPolicyResult',
]

@pulumi.output_type
class GroupMember(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "userId":
            suggest = "user_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GroupMember. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GroupMember.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GroupMember.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 user_id: Optional[builtins.str] = None):
        """
        :param builtins.str user_id: 用户id。
        """
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[builtins.str]:
        """
        用户id。
        """
        return pulumi.get(self, "user_id")


@pulumi.output_type
class PermissionSetPermissionPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "permissionPolicyDocument":
            suggest = "permission_policy_document"
        elif key == "permissionPolicyName":
            suggest = "permission_policy_name"
        elif key == "permissionPolicyType":
            suggest = "permission_policy_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PermissionSetPermissionPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PermissionSetPermissionPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PermissionSetPermissionPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 permission_policy_document: Optional[builtins.str] = None,
                 permission_policy_name: Optional[builtins.str] = None,
                 permission_policy_type: Optional[builtins.str] = None):
        """
        :param builtins.str permission_policy_document: 策略语法内容。语法可参考 策略语法说明。
        :param builtins.str permission_policy_name: 策略名称。
        :param builtins.str permission_policy_type: 策略类型，System or Inline。
        """
        if permission_policy_document is not None:
            pulumi.set(__self__, "permission_policy_document", permission_policy_document)
        if permission_policy_name is not None:
            pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        if permission_policy_type is not None:
            pulumi.set(__self__, "permission_policy_type", permission_policy_type)

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> Optional[builtins.str]:
        """
        策略语法内容。语法可参考 策略语法说明。
        """
        return pulumi.get(self, "permission_policy_document")

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> Optional[builtins.str]:
        """
        策略名称。
        """
        return pulumi.get(self, "permission_policy_name")

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> Optional[builtins.str]:
        """
        策略类型，System or Inline。
        """
        return pulumi.get(self, "permission_policy_type")


@pulumi.output_type
class GetGroupMemberResult(dict):
    def __init__(__self__, *,
                 description: builtins.str,
                 display_name: builtins.str,
                 email: builtins.str,
                 identity_type: builtins.str,
                 join_time: builtins.str,
                 phone: builtins.str,
                 source: builtins.str,
                 user_id: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str description: 用户描述信息
        :param builtins.str display_name: 用户显示名称。
        :param builtins.str email: 用户邮箱。
        :param builtins.str identity_type: 用户身份类型。
        :param builtins.str join_time: 用户加入用户组的时间。
        :param builtins.str phone: 用户手机号。
        :param builtins.str source: 用户来源。
        :param builtins.str user_id: 用户id。
        :param builtins.str user_name: 用户名。
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "identity_type", identity_type)
        pulumi.set(__self__, "join_time", join_time)
        pulumi.set(__self__, "phone", phone)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        用户描述信息
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        用户显示名称。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        用户邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="identityType")
    def identity_type(self) -> builtins.str:
        """
        用户身份类型。
        """
        return pulumi.get(self, "identity_type")

    @property
    @pulumi.getter(name="joinTime")
    def join_time(self) -> builtins.str:
        """
        用户加入用户组的时间。
        """
        return pulumi.get(self, "join_time")

    @property
    @pulumi.getter
    def phone(self) -> builtins.str:
        """
        用户手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter
    def source(self) -> builtins.str:
        """
        用户来源。
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        用户id。
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        用户名。
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetPermissionSetPermissionPolicyResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 permission_policy_document: builtins.str,
                 permission_policy_name: builtins.str,
                 permission_policy_type: builtins.str):
        """
        :param builtins.str created_time: 策略创建时间。
        :param builtins.str permission_policy_document: 策略语法内容。语法可参考 策略语法说明。
        :param builtins.str permission_policy_name: 策略名称。
        :param builtins.str permission_policy_type: 策略类型，System or Inline。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "permission_policy_document", permission_policy_document)
        pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        pulumi.set(__self__, "permission_policy_type", permission_policy_type)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        策略创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> builtins.str:
        """
        策略语法内容。语法可参考 策略语法说明。
        """
        return pulumi.get(self, "permission_policy_document")

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> builtins.str:
        """
        策略名称。
        """
        return pulumi.get(self, "permission_policy_name")

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> builtins.str:
        """
        策略类型，System or Inline。
        """
        return pulumi.get(self, "permission_policy_type")


