# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccountSecureContactInfoArgs',
    'AccountSecureContactInfoArgsDict',
    'AccountTagArgs',
    'AccountTagArgsDict',
]

MYPY = False

if not MYPY:
    class AccountSecureContactInfoArgsDict(TypedDict):
        email: NotRequired[pulumi.Input[builtins.str]]
        """
        安全邮箱。
        """
        email_verified: NotRequired[pulumi.Input[builtins.int]]
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        new_email: NotRequired[pulumi.Input[builtins.str]]
        """
        变更中的新邮箱。
        """
        new_phone: NotRequired[pulumi.Input[builtins.str]]
        """
        变更中的新手机号。
        """
        phone: NotRequired[pulumi.Input[builtins.str]]
        """
        安全手机号。
        """
        phone_verified: NotRequired[pulumi.Input[builtins.int]]
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
elif False:
    AccountSecureContactInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccountSecureContactInfoArgs:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 email_verified: Optional[pulumi.Input[builtins.int]] = None,
                 new_email: Optional[pulumi.Input[builtins.str]] = None,
                 new_phone: Optional[pulumi.Input[builtins.str]] = None,
                 phone: Optional[pulumi.Input[builtins.str]] = None,
                 phone_verified: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] email: 安全邮箱。
        :param pulumi.Input[builtins.int] email_verified: 安全邮箱是否验证，1: 未验证，2: 已验证。
        :param pulumi.Input[builtins.str] new_email: 变更中的新邮箱。
        :param pulumi.Input[builtins.str] new_phone: 变更中的新手机号。
        :param pulumi.Input[builtins.str] phone: 安全手机号。
        :param pulumi.Input[builtins.int] phone_verified: 安全手机号是否验证，1: 未验证，2: 已验证。
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if email_verified is not None:
            pulumi.set(__self__, "email_verified", email_verified)
        if new_email is not None:
            pulumi.set(__self__, "new_email", new_email)
        if new_phone is not None:
            pulumi.set(__self__, "new_phone", new_phone)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if phone_verified is not None:
            pulumi.set(__self__, "phone_verified", phone_verified)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全邮箱。
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "email_verified")

    @email_verified.setter
    def email_verified(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "email_verified", value)

    @property
    @pulumi.getter(name="newEmail")
    def new_email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        变更中的新邮箱。
        """
        return pulumi.get(self, "new_email")

    @new_email.setter
    def new_email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_email", value)

    @property
    @pulumi.getter(name="newPhone")
    def new_phone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        变更中的新手机号。
        """
        return pulumi.get(self, "new_phone")

    @new_phone.setter
    def new_phone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_phone", value)

    @property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全手机号。
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "phone", value)

    @property
    @pulumi.getter(name="phoneVerified")
    def phone_verified(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "phone_verified")

    @phone_verified.setter
    def phone_verified(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "phone_verified", value)


if not MYPY:
    class AccountTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    AccountTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccountTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


